Cinema Roma: programmazione nelle sale | MYmovies.it
Author: MYmovies.it
Description: Programmazione completa delle uscite nelle sale cinematografiche di Roma. Consultabile gratuitamente online, oltre 3000 cinema in tutte le città e comuni d'Italia. Orari, film, cast, critica, trailer, locandina e durata.
Keywords: Roma, programmazione cinema, programmazione sale, cinema, orari, orario, sale, film, telefono, provincia, sale cinematografiche, uscite

- Film 2024
- Film 2023
- Film 2022
- Film 2021
- Film 2020
- Film 2019
- Film 2018
- Film uscita
- Film da vedere
- Film al cinema
- Film commedia
- Film d'animazione
- Film horror
- Film thriller
- Film d'azione
- Film imperdibili
- Film imperdibili 2024
- Film imperdibili 2023
- Film imperdibili 2022
- Film imperdibili 2021
- Film imperdibili 2020
- Film imperdibili 2019
- Film imperdibili 2018
- Trailer

- Serie TV - Tutte le novità
- Serie TV 2024
- Serie TV 2023
- Serie TV 2022
- Serie TV 2021
- Serie TV 2020
- Serie TV 2019
- Le serie tv imperdibili del 2024
- Le serie tv imperdibili del 2023
- Le serie tv imperdibili del 2022
- Le serie tv imperdibili del 2021
- Le serie tv imperdibili del 2020
- Le serie tv imperdibili del 2019

- Mostra del Cinema di Venezia
- Locarno Festival
- Arene Cinevillage
- Magna Graecia Film Festival
- Giffoni
- Cannes a Roma
- Pesaro Film Festival
- Biografilm 2024
- Cannes Film Festival
- Orgoglio e pregiudizio
- Far East Film Festival
- David di Donatello
- Oscar
- Berlinale
- L'eterna illusione
- International Film Festival di Rotterdam
- Torino Film Festival
- Festa del Cinema di Roma

- Film al cinema
- Prossimamente
- Film uscita
- Eventi al cinema
- Eventi Nexo Digital
- I Wonder Stories

- Novità in DVD e Blu-Ray
- I migliori film d'azione in DVD
- I migliori film d'animazione in DVD
- Le migliori commedie di tutti i tempi in DVD
- I migliori film drammatici in DVD
- I migliori western in DVD
- Tutti i film italiani in DVD

- Tutti i film gratis in streaming
- Tutti i film in streaming
- Amazon Prime Video
- AppleTV
- Disney Plus
- Google Play
- Infinity
- Netflix
- NOW
- Iwonderfull
- Paramount Plus
- Rai Play
- Rakuten TV

- Stasera in TV
- Digitale terrestre
- Sky
- Domani in TV
- Tutti i film in tv stasera
- Tutte le serie TV di stasera

- Cinemanews
- Box Office
- Fortune Entertainment
- Nuova Storia del Cinema
- Video recensioni
- The Story of Movies
- Scrivere di cinema

Parte del gruppo
e
Vai alla ricerca avanzata »
Caricamento in corso...

# Cinema Roma

Guida alla programmazione dei film in uscita nelle sale cinematografiche di Roma. Trova il cinema più vicino e gli orari dei film della settimana. Cerca in tutta la provincia di Roma ».

Filtra per: Lingua originale

Per ricevere ogni settimana gli orari dei cinema di Roma lascia qui la tua email


GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.80 - CONSIGLIATO SÌ
CATTIVISSIMO ME 4
Il quarto capitolo riacchiappa tutti i fan della serie con un buonumore contagioso. Animazione, Avventura - USA 2024. Durata 95 Minuti. Consigli per la visione: Film per tutti

MYMOVIES.IT 3.00

CRITICA 2.60

PUBBLICO N.D.
Un film di Chris Renaud, Patrick Delage. Con Max Giusti, Carolina Benvenga, Stefano Accorsi, Steve Carell Uscita 21 agosto 2024. Oggi tra i Film al cinema in 651 sale. Distribuzione Universal Pictures.
Dopo sette anni dall'ultimo Cattivissimo Me, Gru, il supercattivo preferito dal mondo intero, diventato agente della Lega Anti-Cattivi, torna al fianco dei Minions per un'entusiasmante, caotica e audace nuova era. Espandi ▽
Durante la riunione degli ex alunni del Licée Pas Bon, la rinomata scuola dei cattivi, Gru reincontra Maxime Le Mal, un superbad che ce l'ha ancora con lui. Gru, la moglie Lucy, le figlie Margo, Edith e Agnes più l'ultimo arrivato, il neonato Gru Jr, si recano nell'amena cittadina di Mayflower, portando con sé i tre Minion Phil, Ron e Ralph. Lì dovranno relazionarsi con una coppia di vicini spocchiosi e la loro figlia adolescente Poppy. Nel frattempo i dirigenti della Lega trasformano cinque Minion in agenti d'élite dotati di superpoteri e Maxime trasforma la sua ossessione per gli scarafaggi in un'arma contro Gru. Chris Renaud torna alla regia del quarto episodio della saga del Cattivissimo, aggiungendo un nuovo rivale (ma a fine film compariranno anche i rivali dei film precedenti) e un nuovo membro della famiglia di Gru, l'unico figlio naturale e l'unico maschio: di qui forse, l'ossessione che Gru ha nel farsi amare dal neonato. Il film prosegue a rotta di collo intento a riacchiappare tutti i fan della serie, dedicando almeno un momento o una scena a ognuno dei personaggi che il pubblico ha imparato ad amare. Se non ha la forza innovativa del primo film della serie, mantiene comunque un buonumore contagioso e inoffensivo che piacerà ai suoi spettatori affezionati. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
16:00
17:00
18:00
18:40
19:20
20:30
21:00
21:30
22:40
15:00
16:00
17:00
18:00
18:40
19:20
20:30
21:00
21:30
Versione 3D:
16:30
16:30

tel: 066142649

CINEMA Andromeda

20:30
21:30
17:30
18:00
18:30
19:30
20:30
21:30
Versione originale con sottotitoli:
21:00
21:00

tel: 068186655

CINEMA Antares

16:30
17:30
18:30
19:30
21:30
ALTRI CINEMA keyboard_arrow_down

tel: 067610656

CINEMA Atlantic

15:00
16:00
17:00
18:00
19:00
20:00
21:00
22:00
22:50
15:00
16:00
17:00
18:00
19:00
20:00
21:00

tel: 0640419403

CINEMA Barberini

16:00
17:50
19:40
Versione originale con sottotitoli:
21:15
15:00
15:30
17:20
19:15
21:15

tel: 062303408

CINEMA Broadway

18:20
19:00
20:40
22:20
15:30
16:30
17:10
18:20
19:00
20:40
22:20

tel: 065612319

CINEMA Cineland

16:30
17:00
17:30
18:30
19:00
19:30
20:30
16:00
17:00
17:30
18:00
19:00
19:30
20:30

tel: 0688801283 - 0688800888

Eurcine Multisala

20:15
21:15
17:00
18:00
19:00
20:15
21:15

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

20:15
17:00
18:00
19:00
20:15
Versione originale con sottotitoli:
21:15
21:15

tel: 065884230

CINEMA Intrastevere

17:00
Versione originale con sottotitoli:
19:30
21:30
19:30
21:30

tel: 0645472092

CINEMA Jolly

20:30
21:30
22:30
17:30
18:30
19:30
20:30
21:30
22:30

tel: 065417926

CINEMA Madison

15:45
17:00
17:45
18:50
19:35
21:05

tel: 0686391361

CINEMA Multisala Lux

18:30
19:30
20:30
21:30
22:30
16:30
17:30
18:30
19:30
20:30
21:30
22:30
Versione originale con sottotitoli:
16:40

tel: 0686391361

Multisala Odeon

18:30
19:30
21:30
17:30
18:30
19:30
21:30

tel: 0645541398

Nuovo Cinema Aquila

15:40
17:00
18:30
21:00
15:40
17:00
18:30
21:00

tel: 899280273

Stardust Village

20:15
21:15
16:15
17:15
17:45
18:15
19:15
20:15
21:15

The Space Moderno

20:00
21:10
11:00
11:45
13:45
14:15
15:00
15:30
16:00
16:45
17:30
18:00
18:30
19:15
20:00
21:10
Versione originale con sottotitoli:
11:00

The Space Parco de Medici

19:50
20:00
20:25
20:50
21:15
21:35
22:00
22:30
22:55
23:45
00:05
00:15
11:20
11:35
11:50
12:15
14:00
14:30
15:00
15:25
15:45
16:05
16:30
17:00
17:30
17:55
18:15
18:35
19:00
19:40
20:00
20:25
20:45
21:15
21:40
22:00
22:30
23:15
Versione originale con sottotitoli:
11:10
19:00
Versione 3D:
19:30
19:30

tel: 067858158

CINEMA Trianon

16:30
17:30
18:30
19:30
21:30

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

14:00
14:30
14:45
15:00
15:30
16:00
16:30
17:00
17:20
18:00
18:20
19:20
19:45
20:20
20:40
21:15
21:45
22:10
23:30
Versione originale con sottotitoli:
18:55

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

10:30
10:40
11:00
11:30
12:00
12:30
13:30
14:00
14:10
14:25
15:00
15:15
15:30
16:00
16:30
16:50
17:20
17:35
17:50
18:05
18:20
18:45
19:15
20:00
20:30
21:00
21:30
21:45
22:20
Versione originale con sottotitoli:
19:00

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

10:35
11:15
11:45
12:00
12:45
13:00
13:45
14:15
14:45
15:15
15:30
16:15
16:45
17:15
18:00
18:45
19:15
19:45
20:30
21:15
21:45
22:15
23:15
00:10

tel: 892960 (no prefisso)

Uci Luce Maximo

10:50
11:50
13:10
14:00
14:30
15:30
16:20
16:50
17:30
17:50
18:40
19:10
20:10
21:00
21:30
22:30
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Ciampino, Civitavecchia, Colleferro, Fiano Romano, Frascati, Genzano di Roma, Grottaferrata, Guidonia, Trevignano Romano, Velletri oppure cerca Cattivissimo Me 4 in tutta la provincia »
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Cattivissimo Me 4
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.61 - CONSIGLIATO SÌ
L'INNOCENZA
Kore'eda indaga con delicatezza nei dubbi di un preadolescente confuso dal proprio desiderio. Drammatico, Giappone 2023. Durata 126 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.71

PUBBLICO N.D.
Un film di Kore'eda Hirokazu. Con Sakura Andô, Eita, Soya Kurokawa, Hinata Hiiragi Uscita 22 agosto 2024. Oggi tra i Film al cinema in 81 sale. Distribuzione Bim Distribuzione.
Un giovane ragazzo comincia ad assumere strani atteggiamenti. La madre comincia a pensare che sia colpa di un insegnante. Espandi ▽
Preadolescente silenzioso e riservato, Minato ha perso il padre quando era piccolo e vive con la madre, impiegata in una stireria. Vittima a scuola di un professore eccessivamente severo, Minato è difeso dalla madre, la quale si scontra duramente con la preside dell’istituto. Eppure qualcosa non torna: Minato dice la verità o il suo professore è innocente? Dopo la trasferta in Corea del sud con Le buone stelle - Broker, il giapponese Koreeda torna agli spazi domestici e ai contesti tipici del suo cinema. Come sempre, lo scontro fra l’individuo e l’istituzione (qui familiare e scolastica) rifrange il concetto di verità e condiziona emozioni e comportamenti. Prima che un grande narratore delle dinamiche relazioni, familiari e istituzionali, Koreeda è infatti un grande regista e anche in questo suo nuovo Monster inserisce i cinque protagonisti e dà valore soprattutto ai loro movimenti, ai loro sguardi, agli oggetti che li definiscono, alle parole che usano e che vengono fraintese, usate, manipolate. Recensione ❯
OGGI A ROMA

tel: 063612449

Eden Film Center

16:00
18:40
21:00
16:00
18:40
21:00

tel: 0688801283 - 0688800888

Eurcine Multisala

21:16
18:45
21:16

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

17:00
18:45
Versione originale con sottotitoli:
21:15
21:15
ALTRI CINEMA keyboard_arrow_down

tel: 065745825

CINEMA Greenwich

17:00
19:00
Versione originale con sottotitoli:
21:15
21:15

tel: 065884230

CINEMA Intrastevere

19:00
17:00
19:00
Versione originale con sottotitoli:
21:15
21:15

tel: 068559493

CINEMA Mignon

21:15
16:30
18:50
21:15

tel: 0686391361

CINEMA Multisala Lux

19:30
22:00
17:00
19:30
22:00

tel: 0688801283 - 0688800888

Quattro Fontane

19:30
17:00
19:30
Versione originale con sottotitoli:
21:15
21:15

tel: 064957762 064957762

CINEMA Tibur

19:45
17:15
19:45
Versione originale con sottotitoli:
22:00
22:00
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Fiano Romano, Grottaferrata, Trevignano Romano oppure cerca L'Innocenza in tutta la provincia »
Recensione | Cast | Rassegna stampa |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
L'Innocenza
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.69 - CONSIGLIATO NÌ
LA VITA ACCANTO
Una storia curiosamente slegata che sembra fuori fuoco rispetto allo stile del regista. Drammatico, Italia 2024. Durata 100 Minuti.

MYMOVIES.IT 2.50

CRITICA 2.88

PUBBLICO N.D.
Un film di Marco Tullio Giordana. Con Sonia Bergamasco, Paolo Pierobon, Valentina Bellè, Beatrice Barison Uscita 22 agosto 2024. Oggi tra i Film al cinema in 156 sale. Distribuzione 01 Distribution.
La vita di un'influente famiglia vicentina viene sconvolta da un evento imprevedibile. Espandi ▽
Vicenza, 1980. Maria scopre di essere incinta e annuncia con gioia la sua gravidanza al marito Osvaldo. Ma quando la neonata Rebecca viene al mondo ha una vistosa macchia rossa sul viso e Maria la rifiuta, individuando in quella “voglia” l’oscuro segno di un peccato nascosto. Nell’adolescenza la ragazza comincia a reagire all’indifferenza ostile della madre e a porsi le prime domande sulla sua origine. Col tempo Rebecca arriverà ad intuire che le dinamiche famigliari custodiscono quel segreto che ha reso la sua infanzia e adolescenza tanto disfunzionali e infelici. La vita accanto è basato sul romanzo omonimo di Mariapia Veladiano e vanta una sceneggiatura scritta a sei mani da Marco Tullio Giordana, che del film è il regista, Gloria Malatesta e Marco Bellocchio. Le difficoltà nella realizzazione nascono forse proprio dal fatto che la presenza di Bellocchio si avverte in modo dominante rispetto alla narrazione, ma resta secondaria rispetto alla regia. È una storia insolitamente fuori fuoco per un autore di solito centrato come Marco Tullio Giordana, che in passato ha saputo fotografare perfettamente i suoi temi e personaggi. Restano invece efficaci e degne di nota le scenografie austere di Luca Gobbi e le musiche perturbanti di Dario Marianelli. Recensione ❯
OGGI A ROMA

tel: 066142649

CINEMA Andromeda

21:30
17:00
19:15
21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0640419403

CINEMA Barberini

21:30
15:30
17:30
19:30
21:30

tel: 065612319

CINEMA Cineland

15:45
18:00
15:45
18:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

ALTRI CINEMA keyboard_arrow_down

tel: 063612449

Eden Film Center

16:00
18:40
20:00
21:10
16:00
18:40
20:00
21:10

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0688801283 - 0688800888

Eurcine Multisala

21:15
17:00
19:10
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

21:15
17:00
19:10
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 065417926

CINEMA Madison

15:20
17:25
19:30
21:35

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 068559493

CINEMA Mignon

21:15
16:45
19:00
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0686391361

CINEMA Multisala Lux

18:45
21:00
16:30
18:45
21:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0686391361

Multisala Odeon

19:15
21:30
17:00
19:15
21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


The Space Parco de Medici

21:40
16:10
18:50
21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 064957762 064957762

CINEMA Tibur

19:30
21:45
17:00
19:30
21:45

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 067858158

CINEMA Trianon

16:00
18:15
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


CINEMA Troisi

20:15
11:00
18:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

12:50
20:55

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Colleferro, Fiano Romano, Frascati, Genzano di Roma, Grottaferrata oppure cerca La vita accanto in tutta la provincia »
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
La vita accanto
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.05 - CONSIGLIATO SÌ
ALIEN - ROMULUS
La saga di Alien torna alle origini. Álvarez presenta un medley dei capitoli precedenti, con la visceralità da B-Movie. Horror, Fantascienza, Thriller - USA, Gran Bretagna 2024. Durata 119 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 2.94

PUBBLICO 2.71
Un film di Fede Alvarez. Con Cailee Spaeny, Isabela Moner, Archie Renaux, David Jonsson (II) Uscita 14 agosto 2024. Oggi tra i Film al cinema in 326 sale. Distribuzione Walt Disney. V.M. 14
Tornano ancora una volta gli xenomorfi, la Weyland-Yutani Corporation e un equipaggio in larga parte destinato al massacro. Espandi ▽
Rain e il suo androide Andy, che lei cerca di far passare per il proprio fratello, cercano di lasciare la grigia e mefitica colonia mineraria dove vivono per andare su un pianeta in cui si vede il sole. Ma la Weyland-Yutani li incastra con una contraffazione del loro contatto e così non hanno altra scelta che accettare la proposta dell'amico Tyler: rubare alcuni moduli criogenici da una stazione di ricerca spaziale della Weyland-Yutani, per affrontare in proprio il viaggio verso un altro pianeta. La stazione divisa in due sezioni, Romulus e Remus, è abbandonata e prossima a distruggersi nello schianto con un anello planetario, ma ospita i resti di un androide e soprattutto le tracce delle inquietanti creature che hanno massacrato l'equipaggio. Torna alle origini la saga di Alien per il suo primo film targato Disney. Fede Álvarez ci mette la visceralità basilare da B-Movie, ma l'omaggio ai capitoli precedenti della saga ne deraglia la purezza. L'opera è soprattutto un medley dei film precedenti e Álvarez, che pur trova diverse buone idee di sceneggiatura e messa in scena, finisce per adagiarsi troppo nel ruolo di una cover band. I richiami ai capitoli trascorsi sono infatti evidenti, ma le dinamiche tra i personaggi hanno un elemento interessante nel rapporto che gli altri hanno con l'androide Andy, interpretato da un notevole David Jonsson. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:20
17:50
20:30
22:50
15:20
17:50
20:30

tel: 066142649

CINEMA Andromeda

21:40
19:30
21:40

tel: 067610656

CINEMA Atlantic

15:20
17:50
20:20
22:40
15:20
17:50
20:20
ALTRI CINEMA keyboard_arrow_down

tel: 0640419403

CINEMA Barberini

Versione originale con sottotitoli:
21:40
17:20
19:30
21:40

tel: 062303408

CINEMA Broadway

20:00
22:10
20:00
22:10

tel: 065612319

CINEMA Cineland

16:00
18:30
21:00
16:00
18:30
21:00

tel: 065417926

CINEMA Madison

15:30
21:35

tel: 0686391361

CINEMA Multisala Lux

19:30
22:00
17:00
19:30
22:00

tel: 0686391361

Multisala Odeon

22:20
22:20

tel: 899280273

Stardust Village

22:00
18:30
22:00

The Space Moderno

22:30
13:10

The Space Parco de Medici

20:00
21:15
22:20
23:55
11:30
14:10
15:25
17:00
20:00
21:15
22:20

tel: 067858158

CINEMA Trianon

18:00
20:15

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

16:25
19:30
21:40
22:40

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

11:10
16:25
19:10
22:10
22:50
00:05

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

16:50
19:40
22:30

tel: 892960 (no prefisso)

Uci Luce Maximo

11:20
20:00
23:50
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Civitavecchia, Colleferro, Fiano Romano, Frascati, Genzano di Roma, Grottaferrata, Guidonia, Velletri oppure cerca Alien - Romulus in tutta la provincia »
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Alien - Romulus
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.29 - CONSIGLIATO SÌ
MAXXXINE
Terzo film di una riuscita trilogia horror, con Ti West che rivisita con brillantezza lo slasher dell'epoca d'oro. Horror, USA, Nuova Zelanda, Canada 2024. Durata 103 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA 3.58

PUBBLICO N.D.
Un film di Ti West. Con Mia Goth, Elizabeth Debicki, Moses Sumney, Michelle Monaghan Uscita 21 agosto 2024. Oggi tra i Film al cinema in 1 sale. Distribuzione Lucky Red, Universal Pictures. V.M. 14
Dopo il primo X - A Sexy Horror Story e il prequel Pearl, Ti West, scrittore, regista e montatore pluripremiato già noto per altri lavori di genere, ci regala ora il capitolo finale di una trilogia che ha raccolto intorno a sé un'appassionata fan base. Espandi ▽
1985. Maxine è a Hollywood con l'intenzione fermissima di dare una svolta decisiva alla sua vita. Fa l'attrice nel cinema porno, ma si rende conto che è necessario mirare più in alto, passare al cinema "normale". A questo scopo partecipa a un'audizione per una parte nel seguito di un horror di serie B diretto da un'ambiziosa regista. Nonostante la sua provenienza dal porno possa essere un handicap, Maxine non demorde e ottiene il ruolo. Sembra l'inizio della sua realizzazione artistica, ma in città opera un feroce serial killer che ammazza a ripetizione anche pornostar colleghe di Maxine. Inoltre, un detective privato si fa vivo con toni insinuanti e minacciosi: la cerca per conto di qualcuno di potente, una figura misteriosa che emerge da un passato con cui Maxine dovrà fare i conti, mentre lotta per sopravvivere e diventare una star. Mia Goth è, come già in Pearl, il vero fulcro e motore principale del film. Ti West la segue con passione e fa ruotare tutto intorno al suo ritratto sfaccettato e approfondito. Sontuosa è la sua prova; Goth è un'attrice davvero notevole sotto tutti i punti di vista, vanno ricordate, in un ottimo cast, almeno le convincenti prove di un viscidissimo Kevin Bacon nei panni di un detective privato che scherza con il fuoco e dell’affabilmente suave Giancarlo Esposito nel ruolo dell’agente che ogni attrice vorrebbe avere. Recensione ❯
OGGI A ROMA

CINEMA Troisi

Versione originale con sottotitoli:
11:00
18:00
22:30
16:00
20:15
Recensione | Cast | Rassegna stampa |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Maxxxine
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.46 - CONSIGLIATO SÌ
TRAP
Un continuo flirt con l'eccesso, che intende comunicare attraverso il linguaggio della contemporaneità e delle nuove generazioni. Horror, Thriller - USA, Gran Bretagna 2024. Durata 105 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 4.00

PUBBLICO 2.89
Un film di M. Night Shyamalan. Con Josh Hartnett, Hayley Mills, Alison Pill, Saleka Shyamalan Uscita 7 agosto 2024. Oggi tra i Film al cinema in 156 sale. Distribuzione Warner Bros Italia.
Una trama "inusuale" per il regista Shyamalan che ha scelto Josh Hartnett come protagonista. Espandi ▽
Cooper sembra il papà perfetto: accompagna la figlia Riley al concerto del suo idolo, Lady Raven, e fa di tutto per rendere la serata speciale. Almeno finché non scopre che l'evento non è altro che una trappola tesa dall'FBI per catturare il Macellaio, un serial killer implacabile ed efferato. Ma Cooper sa benissimo di chi si tratti. Avrà la meglio l'istinto paterno o l'istinto di sopravvivenza? Dopo il fallimento di L'ultimo dominatore dell'aria, la carriera di M. Night Shyamalan si è sempre più connotata come una successione di esperimenti in produzioni di media grandezza: "piccoli" film, per lo standard di un blockbuster, in cui sperimentare, applicando un metodo da Ai confini della realtà o da Alfred Hitchcock presenta, trasformando i film in altrettante sessioni di laboratorio. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:30
18:00
20:30
22:45
15:30
18:00
20:40

tel: 067610656

CINEMA Atlantic

15:30
15:00

tel: 0640419403

CINEMA Barberini

Versione originale con sottotitoli:
21:30
19:20
21:30
ALTRI CINEMA keyboard_arrow_down

tel: 065612319

CINEMA Cineland

21:00
21:00

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

19:30
17:00
19:30
Versione originale con sottotitoli:
21:30
21:30

tel: 0686391361

CINEMA Multisala Lux

20:30
20:30

The Space Moderno

22:30

The Space Parco de Medici

22:15
11:55
15:55
18:35
22:15

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

19:10
22:30

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

22:50
23:30

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

23:35

tel: 892960 (no prefisso)

Uci Luce Maximo

23:20
01:00
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Colleferro, Guidonia oppure cerca Trap in tutta la provincia »
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Trap
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.79 - CONSIGLIATO SÌ
DEADPOOL & WOLVERINE
Senza freni e totalmente autoriferito, il capitolo migliore della trilogia di Deadpool. Sorprendenti i cameo. Azione, Commedia, Fantascienza - USA 2024. Durata 127 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA 2.90

PUBBLICO 2.48
Un film di Shawn Levy. Con Ryan Reynolds, Hugh Jackman, Emma Corrin, Morena Baccarin Uscita 24 luglio 2024. Oggi tra i Film al cinema in 257 sale. Distribuzione Walt Disney.
Wolverine si sta riprendendo dalle ferite quando incontra il chiacchierone Deadpool. Si alleano per sconfiggere un nemico comune. Espandi ▽
La vita di Wade Wilson non ha preso una bella piega. Negli ultimi anni la sua compagna l'ha lasciato e ora sta frequentando un altro uomo; al lavoro, come venditore di auto al fianco di Peter, gli affari arrancano; il colloquio per entrare negli Avengers è andato malissimo. Wade torna a mettere i panni di Deadpool e si lancia in una assurda impresa, per cui ha assolutamente bisogno di collaborare con una variante di Wolverine. Dopo vari tentativi abortiti, trova un Logan depresso dai molti fallimenti e lo porta con sé per fermare la TVA, che però li esilia entrambi nel "vuoto", un'apocalittica dimensione dominata da Alioth (una grande tempesta dal volto di lupo) e da Cassandra Nova, la folle e potentissima gemella di Charles Xavier. Torna il supereroe più volgare e iperviolento della Marvel in un film senza freni e totalmente autoriferito. Un satirico omaggio all'era Fox-Marvel che, grazie all'alchimia con il Wolverine di Hugh Jackman e alcuni sorprendenti cameo, risulta il capitolo migliore della trilogia di Deadpool. Il film è esattamente quello che ci si aspetta e allo stesso tempo è una sorpresa: battutacce a raffica, rotture della quarta parete, violenza gratuita e costanti strizzate d'occhio al pubblico nerd, dove però si guarda non tanto al mondo Marvel-Disney, bensì al passato Marvel-Fox, omaggiato con un tocco di sincera nostalgia nei titoli di coda. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
17:40
20:20
22:50
15:00
17:40
20:20

tel: 066142649

CINEMA Andromeda

17:00

tel: 067610656

CINEMA Atlantic

17:40
20:20
22:45
17:40
20:20
ALTRI CINEMA keyboard_arrow_down

tel: 0640419403

CINEMA Barberini

Versione originale con sottotitoli:
15:00
17:15

tel: 062303408

CINEMA Broadway

19:30
15:15
19:30

tel: 065612319

CINEMA Cineland

16:00
18:30
21:00
16:00
18:30
21:00

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

Versione originale con sottotitoli:
21:15
21:15

tel: 065417926

CINEMA Madison

15:30
21:35

tel: 0686391361

CINEMA Multisala Lux

18:30
21:00
18:30
21:00

tel: 0686391361

Multisala Odeon

20:00
20:00

tel: 0688801283 - 0688800888

Quattro Fontane

Versione originale con sottotitoli:
21:30
17:00
18:45
21:30

tel: 899280273

Stardust Village

21:30
19:45
21:30

The Space Moderno

23:50

The Space Parco de Medici

20:20
22:05
23:30
11:10
12:15
14:40
15:45
17:35
18:55
20:20
22:05
22:55

tel: 067858158

CINEMA Trianon

22:30

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

16:25
19:50
22:45

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

10:50
16:15
19:45
21:50
22:30
23:50

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

11:00
17:40
18:30
20:00
22:50

tel: 892960 (no prefisso)

Uci Luce Maximo

12:10
19:50
22:40
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Civitavecchia, Colleferro, Fiano Romano, Frascati, Genzano di Roma, Guidonia oppure cerca Deadpool & Wolverine in tutta la provincia »
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Deadpool & Wolverine
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.60 - CONSIGLIATO NÌ
IT ENDS WITH US - SIAMO NOI A DIRE BASTA
Un film che mantiene le promesse del romanzo da cui proviene e dello stile della sua autrice. Drammatico, Sentimentale - USA 2024.

MYMOVIES.IT 2.50

CRITICA 2.70

PUBBLICO N.D.
Un film di Justin Baldoni. Con Blake Lively, Justin Baldoni, Jenny Slate, Hasan Minhaj Uscita 21 agosto 2024. Oggi tra i Film al cinema in 317 sale. Distribuzione Eagle Pictures.
Un dramma sentimentale tratto dall'omonimo romanzo bestseller di Colleen Hoover. Espandi ▽
t Ends With Us - Siamo noi a dire basta è il primo adattamento cinematografico di un romanzo di Colleen Hoover, autrice di chick lit di grande successo: e che qui si resti nell'ambio della chic lit è evidente già dai nomi dei personaggi, degni di una Liala del nostro tempo. Ma qui Hoover si cimenta anche con argomenti più spinosi di quelli generalmente forniti dal genere, ovvero la violenza domestica, e fa un lavoro interessante nel mantenersi sul crinale fra violenza vera e propria e potenziale, poiché i gesti di collera di Ryle - che a ben guardare cominciano con il suo prendere a calci una sedia durante il primo incontro con Lily - sono al confine fra il penalmente perseguibile e il possibilmente accettabile, nell'ambito della caratterizzazione romantica di un bad boy con una dark side. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
17:30
20:20
22:50
15:00
17:30
20:20

tel: 066142649

CINEMA Andromeda

21:40
17:00
19:20
21:40

tel: 067610656

CINEMA Atlantic

15:20
17:50
20:20
22:45
15:20
17:50
20:20
ALTRI CINEMA keyboard_arrow_down

tel: 0640419403

CINEMA Barberini

21:30
19:30
21:30
Versione originale con sottotitoli:
21:30
15:00
16:50
19:10
21:30

tel: 065612319

CINEMA Cineland

16:15
18:30
21:40
16:15
18:45
21:40

tel: 0688801283 - 0688800888

Eurcine Multisala

21:15
17:00
18:45
21:15

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

17:00
19:00
Versione originale con sottotitoli:
21:15
21:15

tel: 0645472092

CINEMA Jolly

20:00
22:30
17:30
20:00
22:30

tel: 0686391361

CINEMA Multisala Lux

19:30
22:00
17:00
19:30
22:00
Versione originale con sottotitoli:
19:00
21:30
16:30
19:00
21:30

tel: 0686391361

Multisala Odeon

19:30
22:00
17:00
19:30
22:00

tel: 899280273

Stardust Village

21:30
16:30
19:00
21:30

The Space Moderno

20:45
22:05
00:05
20:45
21:55

The Space Parco de Medici

20:45
21:50
22:40
23:20
11:40
14:50
17:50
18:50
20:45
21:45
22:40

tel: 067858158

CINEMA Trianon

16:15
18:45
22:30

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

15:15
16:15
16:50
18:30
19:05
19:45
21:30
22:20
23:00

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

11:10
15:00
16:20
17:00
19:20
20:00
21:20
22:10
23:55

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

10:40
12:20
15:20
16:30
18:20
19:30
21:20
22:40
00:15

tel: 892960 (no prefisso)

Uci Luce Maximo

10:40
11:10
14:50
16:00
18:10
19:20
22:15
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Colleferro, Fiano Romano, Frascati, Genzano di Roma, Guidonia, Trevignano Romano, Velletri oppure cerca It Ends With Us - Siamo noi a dire basta in tutta la provincia »
Recensione | Cast | Rassegna stampa |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
It Ends With Us - Siamo noi a dire basta
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER
MYMONETRO
Non ancora disponibile.
BLINK TWICE
Un film difficilmente classificabile, tra horror e revenge femminista, con tanto splatter e humour. Thriller, USA 2024. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA N.D.

PUBBLICO N.D.
Un film di Zoë Kravitz. Con Channing Tatum, Kyle MacLachlan, Adria Arjona, Alia Shawkat Uscita 22 agosto 2024. Oggi tra i Film al cinema in 277 sale. Distribuzione Warner Bros Italia. V.M. 14
La celebre attrice, figlia di Lenny Kravitz e Lisa Bonet, dirige il suo primo film. Espandi ▽
Slater King, un magnate colpevole di un comportamento deplorevole e di un abuso di potere del quale si è scusato pubblicamente si dimette da CEO e fonda un ente di beneficenza che porta il suo nome. Slater ha affrontato un percorso di terapia psicologica atto a rimuovere i traumi del proprio passato e ha comperato un’isola dove trascorrere il suo tempo libero. Ad un incontro della Fondazione King incontra Frida, una donna che lo idolatra, e la invita a fare una vacanza sulla sua isola insieme all’amica Jess: entrambe si uniranno al gruppetto di ospiti vip che ha come unico scopo quello di divertirsi in quell’oasi di bellezza e privilegio. Ma non è tutto oro quello che luccica, e Frida e Jess si renderanno conto che quel luogo incantevole nasconde terribili segreti e ingenera un’inspiegabile inquietudine.
Blink Twice segna il debutto alla regia dell’attrice Zoe Kravitz, figlia del cantante Lenny e dell’attrice Lisa Bonet, ed è una chiara emanazione della sua personalità inquieta e refrattaria alle regole: il suo film è difficilmente classificabile, anche se si muove fra horror e revenge femminista, con tanto splatter e una buona percentuale di humour. Anche la confezione filmica è poco categorizzabile poiché mescola inquadrature ardite, scenari coloratissimi ma inquietanti, e sequenze estreme. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:20
17:50
20:30
22:45
15:20
17:50
20:30

tel: 066142649

CINEMA Andromeda

21:15
17:20
19:15
21:15

tel: 067610656

CINEMA Atlantic

19:30
21:40
19:00
21:00
ALTRI CINEMA keyboard_arrow_down

tel: 0640419403

CINEMA Barberini

15:30
17:30
Versione originale con sottotitoli:
21:45
21:45

tel: 062303408

CINEMA Broadway

21:50
17:30
21:50

tel: 065612319

CINEMA Cineland

15:50
18:40
21:30
15:50
18:40
21:30

tel: 0686391361

CINEMA Multisala Lux

20:30
22:30
16:30
20:30
22:30

tel: 0686391361

Multisala Odeon

20:30
22:30
20:30
22:30

tel: 899280273

Stardust Village

20:15
17:15
20:15

The Space Moderno

19:30
21:30
23:40
18:45
21:20

The Space Parco de Medici

19:25
21:30
00:10
11:05
14:05
16:45
19:25
21:40

tel: 067858158

CINEMA Trianon

20:30
22:30

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

14:00
19:25
22:35

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

13:40
18:50
21:40
00:00

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

11:30
14:20
20:30
23:00

tel: 892960 (no prefisso)

Uci Luce Maximo

11:30
17:20
22:50
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Anzio, Colleferro, Fiano Romano, Frascati, Genzano di Roma, Guidonia, Velletri oppure cerca Blink Twice in tutta la provincia »
Recensione | Cast |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Blink Twice
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.44 - CONSIGLIATO SÌ
INSIDE OUT 2
Un ottimo secondo capitolo che ribalta le premesse del primo e ricrea la fragilità emotiva degli adolescenti. Animazione, USA 2024. Durata 96 Minuti.

MYMOVIES.IT 3.50

CRITICA 3.29

PUBBLICO 3.52
Un film di Kelsey Mann. Con Pilar Fogliati, Deva Cassel, Marta Filippi, Federico Cesari Uscita 19 giugno 2024. Oggi tra i Film al cinema in 127 sale. Distribuzione Walt Disney.
Il film segue Riley durante la sua adolescenza mentre incontra nuove emozioni. Espandi ▽
Riley è diventata officialmente una teenager. Il fatto è che con la pubertà la consapevolezza di sé di Riley è andata in crisi, complice anche la scoperta che le sue due migliori amiche, Grace e Bree, andranno in un liceo diverso dal suo dopo l'estate. Al momento però le tre ragazze sono in partenza per un campo estivo di hockey che durerà tre giorni, durante i quali Riley cercerà di farsi accettare da un nuovo gruppo, una squadra di hockey composta da ragazze più grandi che la vedono come una primina un po' "cringe", tranne Viv, la caposquadra, che prende Riley sotto la sua ala. Ma Riley sta provando nuove emozioni e nella sala comandi della sua psiche, finora abitata da Gioia, Rabbia, Tristezza, Paura e Disgusto, arrivano Ennui, Invidia, Imbarazzo e soprattutto Ansia. Inside Out 2 fa un ottimo lavoro nel ricreare la confusione e la fragilità emotiva che dominano la testa e il cuore degli adolescenti, divorati da sensi di inadeguatezza e inaciditi dal sarcasmo per nascondere le loro false sicurezze. Se la regia di Mann è meno pirotecnica e viscerale di quella di Docter, la sceneggiatura crea un crescendo emotivo che culmina in una commozione finale che coinvolgerà anche quei genitori che riconosceranno l'autolesionismo adolescenziale dei loro figli. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
17:00
19:00
15:00
17:00
19:00

tel: 067610656

CINEMA Atlantic

15:20
17:30
15:20
17:00

tel: 0688801283 - 0688800888

Eurcine Multisala

19:30
17:00
19:30
ALTRI CINEMA keyboard_arrow_down

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

19:30
17:00
19:30

tel: 065417926

CINEMA Madison

15:15
17:45
19:40

tel: 0686391361

CINEMA Multisala Lux

18:30
16:30
18:30

tel: 0686391361

Multisala Odeon

18:00
18:00

tel: 899280273

Stardust Village

16:30

The Space Parco de Medici

11:35
15:10
17:10

tel: 067858158

CINEMA Trianon

16:00
20:30

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

17:30

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

10:35
14:15
16:40

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

11:20
14:00
16:15

tel: 892960 (no prefisso)

Uci Luce Maximo

13:40
15:40
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Grottaferrata, Guidonia oppure cerca Inside Out 2 in tutta la provincia »
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Inside Out 2
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.30 - CONSIGLIATO NÌ
30 ANNI (DI MENO)
Una commedia dalle battute infantili ma con buon ritmo e bravi attori. Commedia, Italia 2024. Durata 102 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 2.50

CRITICA 2.10

PUBBLICO N.D.
Un film di Mauro Graiani. Con Massimo Ghini, Claudio Casisa, Claudio Colica, Antonio Catania Uscita 21 agosto 2024. Oggi tra i Film al cinema in 38 sale. Distribuzione Plaion Pictures.
Una crazy comedy in cui tre settantenni ricoverati in una clinica condividono una inaspettata esperienza. Espandi ▽
Maurizio è un attore e poeta gay che dopo un malore viene ricoverato in una stanza di ospedale insieme al vedovo cardiopatico siciliano Marco e all'"erotomane omofobo" (come lo definisce Maurizio) romano Diego. Poiché Marco ha un appuntamento galante con la cognata, Diego gli procura delle pillole cinesi che dovrebbero funzionare da Viagra, ma che invece lo ringiovaniscono di trent'anni. Anche Maurizio e Diego, sessantenni come Marco, prendono quella pastiglia, ma solo il primo ringiovanisce all'istante, mentre per l'altro il passaggio è più graduale, a cominciare dal rimbiondirsi della capigliatura. I tre fuggono dall'ospedale e decidono di riprodurre la formula delle pillole per commercializzarla. 30 anni (di meno) si avventura lungo i percorsi della commedia surreale all'americana legandola alla commedia regionale italiana, ma il risultato è meno promettente della sua premessa. Gli elementi di interesse in questa storia scombinata ci sarebbero tutti: il desiderio di riscrivere il passato col senno di poi, la voglia di ritrovare la propria identità smarrita nel tempo, la tenerezza in una relazione gay di lunga data, l'amicizia fra tre sessantenni che non hanno apparentemente niente in comune e invece scoprono di potersi voler bene nelle differenze. Quello che invece Graiani gestisce bene è il ritmo registico di commedia, che dà il giusto spazio alle performance degli attori intenti a compensare le fragilità del copione. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
21:00
21:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0645472092

CINEMA Jolly

21:30
17:30
19:30
21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


The Space Parco de Medici

17:45

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

ALTRI CINEMA keyboard_arrow_down

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

21:50

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

19:25

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Guidonia oppure cerca 30 anni (di meno) in tutta la provincia »
Recensione | Cast | Rassegna stampa |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
30 anni (di meno)
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5



MYMONETRO
Non ancora disponibile.
SEVENTEEN TOUR 'FOLLOW' AGAIN TO CINEMAS
Il k-pop dei Seventeen arriva sul grande schermo. Concerto, Corea del sud 2024.

MYMOVIES.IT N.D.

CRITICA N.D.

PUBBLICO N.D.
Un film di Oh Yoon-Dong. Uscita 21 agosto 2024. Oggi tra i Film al cinema in 55 sale. Distribuzione Nexo Digital.
L'elettrizzante primo concerto del gruppo Seventeen al Seoul World Cup Stadium. Espandi ▽
Il film inizia con una potente performance alla luce del giorno che si sviluppa senza soluzione di continuità in un vibrante showcase che esplora tutta la variegata musicalità dei SEVENTEEN. Il film culmina sotto un cielo notturno illuminato da un mare di lightsticks, magnifico festeggiamento dei nove anni di carriera del gruppo e dell'incrollabile devozione della loro fanbase globale. Recensione ❯
OGGI A ROMA

tel: 0686391361

CINEMA Multisala Lux

Versione originale con sottotitoli:
18:30
22:30
18:30
22:30

The Space Moderno

16:20

The Space Parco de Medici

11:40
14:50
16:20
ALTRI CINEMA keyboard_arrow_down

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

Versione originale con sottotitoli:
14:00
16:00

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

Versione originale con sottotitoli:
15:00
16:30

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

Versione originale con sottotitoli:
15:00
17:30

tel: 892960 (no prefisso)

Uci Luce Maximo

Versione originale con sottotitoli:
15:00
CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Guidonia oppure cerca Seventeen Tour 'Follow' Again To Cinemas in tutta la provincia »
Recensione | Cast |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Seventeen Tour 'Follow' Again To Cinemas
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.17 - CONSIGLIATO NÌ
MILLER'S GIRL
Un'operazione intellettuale ambiziosa, dove la parola è predominante. E a tratti soffocante. Drammatico, USA 2024. Durata 93 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 2.50

CRITICA 1.83

PUBBLICO N.D.
Un film di Jade Halley Bartlett. Con Martin Freeman, Jenna Ortega, Bashir Salahuddin, Gideon Adlon Uscita 1 agosto 2024. Oggi tra i Film al cinema in 19 sale. Distribuzione Lucky Red.
Un compito di scrittura creativa produce risultati complessi tra un insegnante e la sua studentessa di talento. Espandi ▽
In un college del Tennessee si incontrano l'adolescente Cairo Sweet, ragazza solitaria che vive in una grande casa colonica, da sempre abituata a combattere la solitudine con la lettura, e il professore di letteratura Jonathan Miller, sposato con l'intellettuale Beatrice e frustrato nelle sue ambizioni di romanziere. Nonostante la differenza d'età e di ruoli, l'attrazione fra i due porta a una relazione intensa, alimentata proprio dalla letteratura ma destinata a restare inappagata. La scrittrice e sceneggiatrice Jade Halley Bartlett esordisce nella regia con una storia imbevuta di letteratura erotica e gotica, tra Henry Miller e il thriller. Nel mondo arguto allestito dalla regista ogni cosa - dagli abiti alla recitazione, alle battute - esplicita la propria altezzosità e sicurezza di sé: il film è un'operazione intellettuale ambiziosa nei toni e molto meno nei risultati, a partire da una messinscena al risparmio e, in fondo, da una complessità testuale che sotto la superficie dell'esercizio di stile argusto e cool nasconde la timida e falsamente pudica analisi di una relazione pericolosa. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

15:00
17:00
17:00

tel: 0688801283 - 0688800888

Eurcine Multisala

19:30
21:15
19:30
21:15

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

21:30
17:00
21:30
ALTRI CINEMA keyboard_arrow_down

tel: 065745825

CINEMA Greenwich

21:30
19:30
21:30

tel: 0688801283 - 0688800888

Quattro Fontane

19:30
21:15
17:00
19:30
21:15
CHIUDI keyboard_arrow_up
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Miller's Girl
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.48 - CONSIGLIATO SÌ
IL MISTERO SCORRE SUL FIUME
Un giallo visionario e suggestivo su un'umanità fragile e impaurita. Drammatico, Cina 2023. Durata 101 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.45

PUBBLICO N.D.
Un film di Shujun Wei. Con Yilong Zhu, Chloe Maayan, Tianlai Hou, Tong Lin Kai Uscita 11 luglio 2024. Oggi tra i Film al cinema in 5 sale. Distribuzione Wanted.
Un poliziotto indaga su degli omicidi della Cina degli anni '90. Espandi ▽
Cina, primi anni 90. Il capitano di polizia Ma Zhe, trasferito in una località della Cina rurale, trova sistemazione per il suo ufficio in una sala cinematografica dismessa. Questa sede improvvisata diverrà il fulcro delle indagini su una serie di delitti insoluti, avvenuti tutti in riva a un fiume. Il sospettato sembra essere un uomo infermo di mente, adottato dalla prima vittima, ma le successive morti confondono le idee su alibi e moventi degli indagati, rivelando nel contempo segreti a lungo taciuti presso la comunità del villaggio. Le pressioni politiche spingono Ma Zhe a chiudere il caso nel modo più semplice, ma il detective vuole andare fino in fondo. Dopo alcuni dialoghi surreali, e l'espediente narrativo della stazione di polizia collocata in un cinema, si comincia a comprendere che le ambizioni del regista vanno ben oltre. Wei Shujun adatta un racconto di Yu Hua e lo trasforma in un omaggio cinéphile a certo cinema onirico anni 70. Un'umanità fragile e impaurita sembra inconsapevole del proprio destino, protesa a nascondere la propria natura per preservare le maschere dello status quo. Un lavoro suggestivo, destinato a rivelarsi più compiutamente in una seconda visione, che aiuta a comprendere i simbolismi dell'ultimo ed enigmatico segmento. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

16:00
21:25

tel: 0645541398

Nuovo Cinema Aquila

18:45
21:00
18:45
21:00

tel: 063236588

CINEMA Tiziano

Versione originale con sottotitoli:
18:00
20:30
Recensione | Cast | Rassegna stampa |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Il mistero scorre sul fiume
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.18 - CONSIGLIATO NÌ
BORDERLANDS
Un pastiche che prende da ogni altro medium tutto quello che gli serve per restituirci un ritmo sempre più pesante. Azione, Avventura, Commedia - USA 2024. Durata 102 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 2.00

CRITICA 2.29

PUBBLICO 2.25
Un film di Eli Roth. Con Cate Blanchett, Kevin Hart, Jack Black, Ariana Greenblatt Uscita 7 agosto 2024. Oggi tra i Film al cinema in 25 sale. Distribuzione Eagle Pictures.
In un pianeta di nome Pandora le persone vanno alla ricerca di una reliquia misteriosa. Espandi ▽
Lilith (Blanchett), una famigerata cacciatrice di taglie dal passato misterioso, è costretta a tornare, a malincuore, su Pandora, il suo pianeta natale che è il più caotico della galassia. La sua missione è trovare la figlia scomparsa di Atlas (Ramírez), il più potente figlio di p*****a dell'universo. Lilith stringerà un'alleanza con un'improbabile squadra di reietti: Roland (Hart), un mercenario esperto, Tiny Tina (Greenblatt), una adolescente amante degli esplosivi e il suo muscoloso protettore Krieg (Munteanu), Tannis (Curtis), una scienziata pazza che ne ha viste di tutti i colori e Claptrap (Black), un robottino logorroico e saccente. Insieme, questi strampalati eroi dovranno sconfiggere una specie aliena e pericolosi banditi e scopriranno uno dei segreti più incredibili di Pandora. Il destino dell'universo potrebbe essere nelle loro mani, ma alla fine combatteranno per qualcosa di più grande: la loro amicizia. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

22:55
15:00

The Space Parco de Medici

11:45
16:20

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

14:00
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Borderlands
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER
MYMONETRO
Non ancora disponibile.
WHEN IN ROME
Una commedia romantica dedicata all'amore duraturo, una storia di umanità e rimpianti. Drammatico, Danimarca, Italia, Svezia 2024. Durata 98 Minuti.

MYMOVIES.IT 3.00

CRITICA N.D.

PUBBLICO N.D.
Un film di Niclas Bendixen. Con Bodil Jørgensen, Kristian Halken, Rolf Lassgård, Davide Iachini Uscita 21 agosto 2024. Oggi tra i Film al cinema in 4 sale. Distribuzione Circuito Cinema, Vivo Film.
Una commedia sentimentale che non rinuncia a giocare con i cliché del Belpaese. Espandi ▽
Gerda e Kristoffer vivono a Copenhagen, sono sposati da quarant’anni e hanno una bellissima figlia di nome Charlotte, di cui sono orgogliosi. È proprio Charlotte a regalare ai genitori un viaggio a Roma: quale luogo migliore della città dell’amore per festeggiare il loro quarantesimo anniversario? I due partono così in aereo, con disappunto di Gerda che avrebbe preferito viaggiare in treno, e raggiungono la città eterna. Per Kristoffer è la prima volta nella capitale italiana, mentre sua moglie vi ha trascorso gli anni dell’università, quando studiava storia dell’arte. Giunti a destinazione Kristoffer si addormenta in albergo, Gerda esce da sola per esplorare la città. Passeggiando per le vie di Roma, riemergono i ricordi del passato. Diretto da Niclas Bendixen, When in Rome racconta con ironia e delicatezza la storia d’amore fra due sessantenni danesi giunti al loro quarantesimo anno di matrimonio. Fra dialoghi arguti e forsennati, il film costruisce un’atmosfera intrigante e misteriosa, perdendosi tuttavia nel finale, che tradisce la promessa di profondità dell’originale parte iniziale. Recensione ❯
OGGI A ROMA

tel: 0688801283 - 0688800888

Eurcine Multisala

Versione originale con sottotitoli:
21:16
17:01
21:16

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 0688801283 - 0688800888

Quattro Fontane

Versione originale con sottotitoli:
22:00
17:00
19:00
22:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
When in Rome
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
4.02 - ASSOLUTAMENTE SÌ
PERFECT DAYS
Il ritratto della serena e composta solitudine di un uomo che ha fatto pace con i suoi errori del passato. Drammatico, Giappone 2023. Durata 123 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.00

CRITICA 4.17

PUBBLICO 3.89
Un film di Wim Wenders. Con Kôji Yakusho, Tokio Emoto, Arisa Nakano, Aoi Yamada Uscita 4 gennaio 2024. Oggi tra i Film al cinema in 2 sale. Distribuzione Lucky Red.
Hirayama fa una vita semplice e ha una quotidianità molto strutturata. È un appassionato di musica, libri e alberi che gli piace fotografare. Il suo passato però riemergerà attraverso incontri inaspettati. Espandi ▽
Perfect Days racconta le “giornate perfette” di Hirayama come una quieta affermazione di dignità quotidiana. L’uomo svolge il suo lavoro con gesti precisi ed essenziali, accogliendo l’occasionale contatto umano (anche nella forma anonima di una partita a tris proposta su un foglietto) con generosità e rispetto. Tutto in lui è rimasto analogico, come le musicassette che ascolta o la macchina fotografica i cui rullini vanno fatti sviluppare, e le fotografie vengono collezionate in scatole numerate che archiviano la nostalgia del tempo che passa. Wim Wenders, in veste di regista e sceneggiatore (con Takuma Takasaki), mette a frutto la sua grande familiarità con il documentario per creare un film di finzione che segue le giornate del suo protagonista come una camera nascosta, e poi però racconta i sogni di Hirayama come un’elaborazione artistica del giorno appena vissuto. Koji Yakuso è lo straordinario interprete di questo film quasi muto che si snoda in purezza attraverso uno sguardo contemplativo ma mai artefatto. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

21:35
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Perfect Days
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
4.05 - ASSOLUTAMENTE SÌ
LA ZONA D'INTERESSE
Un'opera di cui si parlerà a lungo. Un laboratorio di analisi della banalità del male con la straordinaria Sandra Hüller. Drammatico, Storico - Gran Bretagna, Polonia, USA 2023. Durata 105 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.50

CRITICA 4.09

PUBBLICO 3.56
Un film di Jonathan Glazer. Con Christian Friedel, Sandra Hüller, Johann Karthaus, Luis Noah Witte Uscita 22 febbraio 2024. Oggi tra i Film al cinema in 9 sale. Distribuzione I Wonder Pictures.
La vita del comandante di Auschwitz e sua moglie nei pressi del campo di concentramento. Espandi ▽
Rudolf Höss e famiglia vivono la loro quiete borghese in una tenuta fuori città, tra gioie e problemi quotidiani: lui va al lavoro, lei cura il giardino e i figli giocano tra loro o combinano qualche marachella. C'è un dettaglio però. Accanto a loro, separato solo da un muro, c'è il campo di concentramento di Auschwitz, di cui Rudolf è il direttore. A dieci anni di distanza da Under the Skin, acclamato universalmente come una delle opere che ha meglio colto le inquietudini della contemporaneità, Jonathan Glazer si ripresenta con la trasposizione di un romanzo di Martin Amis: un film ambizioso e collocato in un'epoca storica tristemente nota, quella degli anni '40 e della messa in atto della Soluzione Finale da parte dei nazisti. Ma è chiaro fin da subito come non sia la ricostruzione storica a interessare il regista, bensì la messa in scena di una situazione paradossale, così estrema da trasformarsi in un laboratorio di analisi della banalità del male e della separazione tra percezione soggettiva e realtà oggettiva. Recensione ❯
OGGI A ROMA

tel: 063612449

Eden Film Center

16:15
18:15
16:15
18:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 065417926

CINEMA Madison

15:45
21:35

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
La zona d'interesse
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




VIDEO RECENSIONE TRAILER

MYMONETRO - GIUDIZIO MEDIO
4.07 - ASSOLUTAMENTE SÌ
UN AFFARE DI FAMIGLIA
Il maestro dei rapporti famigliari eleva il suo linguaggio con un'amara analisi delle disuguaglianze sociali. E diventa un classico vivente. Drammatico, Giappone 2018. Durata 121 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.50

CRITICA 4.10

PUBBLICO 3.61
Un film di Kore'eda Hirokazu. Con Lily Franky, Sakura Andô, Mayu Matsuoka, Kirin Kiki, Jyo Kairi Uscita 13 settembre 2018. Oggi tra i Film al cinema in 1 sale. Distribuzione Bim Distribuzione.
La famiglia, per definizione, non si sceglie. O forse la vera famiglia è proprio quella che si ha la rara facoltà di scegliere. Espandi ▽
In un umile appartamento vive una comunità di persone che sembra unita da legami di parentela. Così non è, nonostante la presenza di una nonna, di una coppia e una bambina trovata per strada. La famiglia, per definizione, non si sceglie, o forse la vera famiglia è proprio quella che si ha la facoltà di scegliere. Il “libero arbitrio parentale” è un tema ricorrente nel cinema di Kore'eda: dallo scambio di figli di Father and Son alla sorellanza estesa di Little Sister.
Buoni, cattivi, giusto e sbagliato, diventano concetti ribaltati sullo spettatore e sui suoi dubbi, con una padronanza della narrazione che guarda Akira Kurosawa, ancor più che al consueto termine di paragone di Ozu. Con Un affare di famiglia si ride, ci si commuove e si rischia di finire con il cuore in frantumi. Mai così pessimista, e mai così lucido, Kore-eda è ormai un classico vivente. Recensione ❯
OGGI A ROMA

tel: 065745825

CINEMA Greenwich

Versione originale con sottotitoli:
21:30
21:30
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Un affare di famiglia
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.70 - CONSIGLIATO SÌ
ANATOMIA DI UNA CADUTA
Una tesa e inquietante storia di doppie verità che ribalta i ruoli di coppia tradizionali. Con due attori superbi. Drammatico, Francia 2023. Durata 150 Minuti.

MYMOVIES.IT 4.00

CRITICA 3.76

PUBBLICO 3.34
Un film di Justine Triet. Con Sandra Hüller, Swann Arlaud, Milo Machado Graner, Antoine Reinartz Uscita 26 ottobre 2023. Oggi tra i Film al cinema in 4 sale. Distribuzione Teodora Film.
Una donna è sospettata dell'omicidio del marito. Il loro figlio cieco dovrà affrontare un dilemma morale essendo l'unico testimone. Espandi ▽
Anatomy of a Fall utilizza i meccanismi del film di indagine quelli del “courtroom drama” per parlare d’altro: infatti non va valutato come esempio riuscito dei due generi, dei quali non ha la coerenza ermetica, ma come esplorazione metaforica di una relazione di coppia come questione supremamente percettiva. La regista francese Justine Triet alza parecchio il tiro rispetto al suo precedente Sibyl nel creare una storia (scritta insieme all’attore e sceneggiatore Arthur Harari) tesa e inquietante che compie una scelta fondamentale: quella di ribaltare i ruoli di coppia tradizionali. L’altro asso nella manica di Triet sono due superbi attori: Swann Arlaud nel ruolo dell’avvocato Renzi e soprattutto Sandra Huller in quello della protagonista sua omonima (il che fa venire il sospetto che la parte sia stata scritta su di lei): la sua risata, allo stesso tempo salvifica e ferina, è al centro di una caratterizzazione magistrale. Recensione ❯
OGGI A ROMA

tel: 063612449

Eden Film Center

16:45
20:45
16:45
20:45

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Anatomia di una caduta
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.01 - CONSIGLIATO SÌ
UN MONDO A PARTE
Antonio Albanese è ancora una volta all'altezza, in una favola sulla solidarietà umana. Sorprendente Virginia Raffaele. Commedia, Italia 2024. Durata 113 Minuti.

MYMOVIES.IT 3.00

CRITICA 2.92

PUBBLICO 3.12
Un film di Riccardo Milani. Con Antonio Albanese, Virginia Raffaele, Sergio Saltarelli, Alessandra Barbonetti Uscita 28 marzo 2024. Oggi tra i Film al cinema in 5 sale. Distribuzione Medusa.
Cercare in tutti i modi di salvare una scuola speciale. Antonio Albanese torna protagonista di una commedia diretta da Riccardo Milani. Espandi ▽
Michele Cortese è un maestro elementare che chiede l'assegnazione provvisoria presso una scuola di Rupe, un paesino sperduto dell'alta Val di Sangro, nel cuore del Parco nazionale dell'Abruzzo, che conta 378 anime - anzi, 364 perché l'anno prima ci sono state "14 dipartite e nessuna nascita". Quando Michele arriva alla scuola del nuovo incarico scopre che dovrà insegnare ad una pluriclasse di soli sette bambini fra prima, terza e quinta elementare. E in breve scoprirà anche che il preside del comprensivo di una cittadina più grande ha tutto l'interesse a che la scuola di Rupe chiuda i battenti. Toccherà al maestro Cortese e alla vicepreside Agnese, insieme al personale scolastico, ai bambini e agli abitanti di Rupe, tentare di salvare il proprio presidio educativo con un escamotage davvero audace. Riccardo Milani torna a scegliere Antonio Albanese come suo alter ego, con cui condivide le caratteristiche di generosità d'animo, impegno civile e comune decenza. Un mondo a parte è una favola intenzionata a tradurre in forma di commedia popolare un depauperamento tangibile e lo spettro di una generale rassegnazione "a perdere una cosa dopo l'altra", riconducendoci ad un principio base di solidarietà umana. Albanese è come al solito all'altezza del ruolo, ma sorprende per efficacia Virginia Raffaele sia per la capacità di calarsi a fondo, lei romana, nell'accento di sua madre, sia per quella di impersonare in modo riconoscibile una delle tante figure scolastiche che combattono una quotidiana battaglia. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

17:40
19:35
17:40
19:35

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Un mondo a parte
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




VIDEO RECENSIONE TRAILER

MYMONETRO - GIUDIZIO MEDIO
2.83 - CONSIGLIATO SÌ
VAN GOGH - SULLA SOGLIA DELL'ETERNITÀ
Van Gogh secondo Schnabel, il ritratto umano di un'anima errante e della sua ricerca di un posto nella società. Biografico, Drammatico - USA 2018. Durata 110 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA 2.50

PUBBLICO 3.00
Un film di Julian Schnabel. Con Willem Dafoe, Rupert Friend, Oscar Isaac, Mathieu Amalric Uscita 3 gennaio 2019. Distribuzione Lucky Red.
I tormenti interiori del pittore Vincent Van Gogh. Espandi ▽
È di sole che ha bisogno Vincent van Gogh, insofferente a Parigi e ai suoi grigi. Confortato dall'affetto del fratello Theo, Vincent si trasferisce ad Arles, ma la permanenza è turbata dalle nevrosi incalzanti e dall'ostilità dei locali, che biasimano la sua arte. A colpi di pennellate nervose, arriverà bruscamente alla fine dei suoi giorni.
Ventidue anni dopo Basquiat, Julian Schnabel trasloca in Francia per raccontare il bisogno permanente di Van Gogh di dipingere. Come per Basquiat, non cerca di penetrare l'enigma della creazione. Quello che gli interessa è rendere conto del mondo nel quale viveva, dove l'impressionismo era l'arte dominante, perché è in quel mondo che ritroviamo le convenzioni sociali che lo rigettano. Alle torsioni delle sue tele, il regista risponde con gli strumenti del cinema provando a suo modo a governare il caos. Recensione ❯
OGGI A ROMA

tel: 060608

Teatro all'Aperto Ettore Scola

21:00
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Van Gogh - Sulla soglia dell'eternità
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.61 - CONSIGLIATO SÌ
LA CHIMERA
Un film al contempo arcaico e postmoderno, completamente libero come sa essere il cinema di Alice Rohrwacher. Drammatico, Italia 2023. Durata 134 Minuti.

MYMOVIES.IT 3.50

CRITICA 3.46

PUBBLICO 3.86
Un film di Alice Rohrwacher. Con Josh O'Connor, Carol Duarte, Vincenzo Nemolato, Alba Rohrwacher Uscita 23 novembre 2023. Oggi tra i Film al cinema in 4 sale. Distribuzione 01 Distribution.
Ambientato negli anni '80, nel mondo clandestino dei "tombaroli", il film racconta di un giovane archeologo inglese coinvolto nel traffico clandestino di reperti archeologici. Espandi ▽
La chimera racconta una ricerca ostinata – di morte, di vita, di riscatto dalla povertà e di accumulo materiale – con il passo folk del cantastorie, evidenziandone il lato picaresco e quello simbolico. È un film completamente libero come sa esserlo il cinema di Alice Rohrwacher, che sceglie il tempo del racconto cominciando lentamente, per dare al suo protagonista lo spazio di una rincorsa fatale, e accelerando in “ascese velocissime” che rivelano una comicità da film muto. Ha i colori delle fiabe e l’apparente scanzonatura degli stornelli, attraversa un’Italia nel processo di essere svenduta agli stranieri ma in cui due stranieri sembrano gli unici a volerne conservare il mistero, ci aiuta a “stimare l’inestimabile” e a rivendicare la tutela delle “cose che appartengono a tutti” perché la proprietà non deve essere necessariamente possesso. E il cinema di Rohrwacher si conferma qui contemporaneamente arcaico e postmoderno, nonché capace di inventare parabole agresti che presagiscono, come il migrare degli uccelli, la transizione verso il degrado a seguire. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
La Chimera
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.56 - CONSIGLIATO SÌ
LA SALA PROFESSORI
Lo stato di crisi dell'istituzione scolastica raccontato senza retorica e senza sconti. Drammatico, Germania 2023. Durata 98 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.50

PUBBLICO 3.69
Un film di Ilker Çatak. Con Leonie Benesch, Leonard Stettnisch, Michael Klammer, Rafael Stachowiak Uscita 29 febbraio 2024. Oggi tra i Film al cinema in 3 sale. Distribuzione Lucky Red.
Un'insegnante decide di indagare sulla questione che vede uno dei suoi alunni sospettato per furto. Espandi ▽
Quando la nuova insegnante di matematica e di educazione fisica di una seconda media tedesca, Carla Nowak, decide di prendere l'iniziativa per scoprire chi è il responsabile dei furti che si sono verificati nella scuola, lo fa con le migliori intenzioni. Eppure la sua azione finisce per innescare una reazione a catena, che sfocia proprio là dove Nowak non avrebbe mai voluto, in quell'immagine finale, che è iconograficamente associabile a una vittoria, ma racconta una tragica sconfitta. La sala professori fotografa con la giusta drammaticità lo stato di un'istituzione in grossa crisi, esogena e endogena, in cui il rispetto che un tempo era precetto è stato sostituito dal sentimento umorale, per cui all'insegnante si dà retta finché è simpatico, sa intrattenere, non si fa scudo con il suo ruolo, perché allora quello scudo, sebbene di latta, diventa subito il bersaglio del tiro incrociato di alunni e genitori. Con passo felpato e occhio lucido, sostenuto da una colonna sonora asciutta e perfetta, Çatak segue l'intensa Leonie Benesch affondare nella spirale del tutti contro tutti, senza mai smettere di opporre resistenza, anche solo con lo sguardo, e mantiene saggiamente il film nell'ambito del verosimile. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

17:50
19:40

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
La sala professori
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
4.09 - ASSOLUTAMENTE SÌ
IL SIGNORE DEGLI ANELLI - IL RITORNO DEL RE
Un Peter Jackson in stato di grazia nel concepire il più incredibile degli epiloghi, nel liberare un lungo respiro epico. Fantastico, Nuova Zelanda, USA, Germania 2004. Durata 201 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.00

CRITICA N.D.

PUBBLICO 4.18
Un film di Peter Jackson. Con Elijah Wood, Cate Blanchett, Ian Holm, Ian McKellen Uscita 25 luglio 2024. Oggi tra i Film al cinema in 92 sale. Distribuzione Warner Bros Italia.
Il Re è tornato. L'avevamo lasciato "ramingo" vincitore nel fosso di Helm e lo ritroviamo "blasonato" e "armato" della spada dei re (Narsil), ri-forgiata dalla sapienza di Elrond , nell'ultima epica battaglia contro l'Oscuro Signore di Mordor. Espandi ▽
L'ex Compagnia dell'Anello si prepara per la battaglia finale per la Terra di Mezzo, mentre Frodo e Sam approcciano il Monte Fato per distruggere l'Unico Anello. Recensione ❯
OGGI A ROMA

The Space Parco de Medici

21:00
11:10
18:20
21:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

17:10
21:10

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

17:40
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

ALTRI CINEMA keyboard_arrow_down

tel: 892960 (no prefisso)

Uci Cinemas Roma Est

21:20

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 892960 (no prefisso)

Uci Luce Maximo

21:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

CHIUDI keyboard_arrow_up
In provincia di Roma anche a: Genzano di Roma, Guidonia oppure cerca Il signore degli anelli - Il ritorno del re in tutta la provincia »
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Il signore degli anelli - Il ritorno del re
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.36 - CONSIGLIATO SÌ
ADAGIO
Sollima torna a raccontare una Roma disperata e crepuscolare in una crime story di forte impatto. Drammatico, Italia 2023. Durata 127 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.19

PUBBLICO 3.40
Un film di Stefano Sollima. Con Pierfrancesco Favino, Toni Servillo, Valerio Mastandrea, Adriano Giannini Uscita 14 dicembre 2023. Oggi tra i Film al cinema in 1 sale. Distribuzione Vision Distribution. V.M. 14
Stefano Sollima conclude la trilogia romana iniziata con A.C.A.B nel 2012 e proseguita con Suburra nel 2015. Espandi ▽
Dopo essersi affermato anche all'estero come un tecnico dalle mani sicure, capace di dirigere buoni action muscolari, Stefano Sollima torna nella sua Roma. Ne aveva esplorato il sottobosco più oscuro in film come Acab e Suburra, oltre che nella serie che lo ha lanciato, Romanzo criminale. Ma in questa storia di bassa malavita, tra vecchi gangster malmessi e forze dell'ordine corrotte, sullo sfondo di una città in fiamme a un soffio dal post-apocalittico, Sollima trova una delle sue opere più compiute e mature. L'azione senza il cuore e la testa conta poco, e rispetto anche a quanto fatto in passato Adagio beneficia enormemente di un rapporto diverso con il luogo che racconta: è forse la prima volta che si va oltre un certo sensazionalismo sulla Roma in rovina, che sembra sempre sottintendere un facile commento sociale solo perché di moda a livello nazionale. Recensione ❯
OGGI A ROMA

Cinevillage Villa Lazzaroni

21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Adagio
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.73 - CONSIGLIATO SÌ
PALAZZINA LAF
Il fulminante esordio alla regia di Michele Riondino porta con sé l'eredità di molto cinema. Drammatico, Italia 2023. Durata 99 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.00

CRITICA 3.37

PUBBLICO 3.82
Un film di Michele Riondino. Con Michele Riondino, Elio Germano, Vanessa Scalera, Domenico Fortunato Uscita 30 novembre 2023. Oggi tra i Film al cinema in 7 sale. Distribuzione Bim Distribuzione.
Un film dal solido impianto civile e dagli echi grotteschi e arrabbiati che rimandano a La classe operaia va in paradiso di Elio Petri. Espandi ▽
1997. All’ILVA di Taranto è appena avvenuta l’ennesima morte sul lavoro, ma Caterino Lamanna, operaio addetto ai lavori di fatica nell’industria siderurgia, è pronto a darne la colpa ai sindacati. Caterino è un cane sciolto che pensa al suo imminente matrimonio con la giovane albanese Anna e si fa i fatti suoi, finché Giancarlo Basile, dirigente dell’ILVA, non lo recluta per “farsi un giro e dirgli quello che succede” in fabbrica, e resoconti in particolare le attività del sindacalista Renato Morra, che infiamma gli animi degli operai e li spinge alla ribellione. Basile offre a Lamanna la promozione a caposquadra e l’auto aziendale, ma Caterino chiede di essere mandato alla Palazzina Laf pensando che sia un luogo di privilegio riservato a pochi eletti. In realtà è un edificio in disarmo, incrocio fra una riserva indiana, un manicomio e una prigione, dove sono rinchiusi in orario di lavoro i dipendenti qualificati che hanno fatto l’onda, e che quindi sono invitati a licenziarsi o ad accettare un incarico demansionato e incoerente con la loro preparazione.
Palazzina Laf segna l’esordio alla regia dell’attore Michele Riondino, ed è un esordio fulminante, che porta con sé non solo la conoscenza approfondita della storia ignobile dell’ILVA e delle sue ricadute sul territorio tarantino (dove Riondino è nato e cresciuto), ma anche l’eredità di molto cinema, dalla saga grottesca di Fantozzi fino all’alienazione stralunata di La pecora nera di Ascanio Celestini, Brazil di Terry Gilliam e Tony Manero di Pablo Larrain. Recensione ❯
OGGI A ROMA

tel: 3483815417

Arena Garbatella

21:20

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 065417926

CINEMA Madison

17:50
19:40

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Palazzina Laf
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.44 - CONSIGLIATO SÌ
CHALLENGERS
Guadagnino dirige un'esplorazione - maliziosamente - seduttiva del desiderio. Che rimbalza come una pallina da tennis. Drammatico, USA 2024. Durata 131 Minuti.

MYMOVIES.IT 3.50

CRITICA 3.71

PUBBLICO 3.10
Un film di Luca Guadagnino. Con Zendaya, Josh O'Connor, Mike Faist, Scottie DiGiacomo Uscita 24 aprile 2024. Distribuzione Warner Bros Italia.
Luca Guadagnino dirige un film ambientato nel mondo del tennis ma incentrato sulla rivalità (anche amorosa) tra tre ragazzi. Espandi ▽
Art e Patrick sono amici da quando avevano 12 anni, ed entrambi giocano a tennis sognando una carriera da professionisti. Ma quando in campo scende Tashi, la giocatrice più brillante della sua generazione, la loro amicizia viene messa alla prova dalla competizione per le sue attenzioni. Anni dopo, quando Art, che nel frattempo è diventato una star del tennis (ma sta ancora inseguendo il sogno di vincere gli US Open), partecipa a un challenger, ovvero un incontro di livello inferiore nel mondo dei tornei professionistici, si trova di fronte proprio Patrick, che nel frattempo si è perso per strada, riducendosi a dormire nella sua automobile. E sarà sempre Tashi l'ago della bilancia fra quei due sfidanti. Challengers, scritto dal drammaturgo e romanziere Justin Kuritzkes e diretto da Luca Guadagnino, è una esplorazione geometrica del desiderio che rimbalza come una pallina da tennis e colpisce gli avversari a 200 chilometri all'ora, quasi la velocità del proiettile. Nella sua voglia di giocare con la natura volubile e feroce del desiderio e con le dinamiche del dominio e della sottomissione, il film ha in sé qualcosa di ludicamente, e maliziosamente, seduttivo. Recensione ❯
OGGI A ROMA

tel: 06490377

Cinevillage Piazza Vittorio

21:15
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Challengers
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.82 - CONSIGLIATO SÌ
L'ARTE DELLA GIOIA
Un arazzo dalla confezione infinitamente accattivante, dove l'ironia è il gesto di suprema rivendicazione femminile. Drammatico, Italia 2024. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.00

CRITICA 3.55

PUBBLICO 3.90
Una serie di Valeria Golino, Nicolangelo Gelormini. Con Tecla Insolia, Jasmine Trinca, Valeria Bruni Tedeschi, Guido Caprino Uscita 30 maggio 2024. Oggi tra i Film al cinema in 1 sale. Distribuzione Vision Distribution.
Valeria Golino porta sullo schermo il complesso romanzo postumo di Goliarda Sapienza. Espandi ▽
Modesta cresce nella campagna siciliana insieme alla madre. Quando suo padre, da tempo assente, ricompare è per abusare di lei e del suo immenso bisogno di affetto. E Modesta si vendica. Nel convento per figlie dell'aristocrazia siciliana dove viene accolta diventa la favorita della madre superiora Eleonora, di cui si innamora. Ma l'idillio non durerà a lungo e Modesta, ormai una giovane donna, si ritrova nella casa di una principessa del Nord Italia capricciosa ed esigente, e si innamora di nuovo: di una sua coetanea, di un autista, di un "gabellotto". Ognuno di questi incontri è un passo avanti nel suo percorso di autoconsapevolezza e determinazione. Trasformare un romanzo fluviale e debordante come "L'arte della gioia" di Goliarda Sapienza in una miniserie è stato un azzardo e un atto di amore da parte di Valeria Golino. La confezione della serie è impeccabile e infinitamente accattivante, ha un afflato pittorico e una grande attenzione al dettaglio d'epoca. La regista estrae dal magma narrativo del romanzo di Sapienza una figurina determinata e inscalfibile, un agente del caos (per gli altri) cui dà corpo e soprattutto sguardo (reso metallico dai costanti riflessi di luce all'interno delle iridi brune) l'ottima Tecla Insolia, onnipresente senza stancare lo spettatore. Recensione ❯
OGGI A ROMA

tel: 065884230

CINEMA Intrastevere

20:00
17:00
20:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
L'arte della gioia
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




VIDEO RECENSIONE TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.16 - CONSIGLIATO SÌ
LE VERITÀ
Kore-eda si cala splendidamente nel cinema francese con una ricca storia di confronto familiare. Drammatico, Francia 2019. Durata 107 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.39

PUBBLICO 2.60
Un film di Kore'eda Hirokazu. Con Catherine Deneuve, Juliette Binoche, Ethan Hawke, Clémentine Grenier, Manon Clavel Uscita 10 ottobre 2019. Distribuzione Bim Distribuzione.
Il rapporto tormentato tra una madre che si sta preparando per un ruolo in un film di fantascienza e la figlia. Espandi ▽
“Preferisco essere una cattiva madre e amica, ma una brava attrice” Diva del cinema francese, Fabienne riceve la visita della figlia Lumir, sceneggiatrice che vive a New York. Nella villa parigina di Fabienne le due donne faranno i conti con il passato nonostante la presenza delle famiglie e l’impegno di Fabienne sul set, per girare un film che confonde ancor di più i ruoli delle madri e delle figlie. Nel 2018 ha vissuto la consacrazione con Un affare di famiglia, Palma d’oro a Cannes e grande successo internazionale. Ora, l’autore giapponese Kore-eda dirige due dive come Catherine Deneuve e Juliette Binoche, riuscendo a creare una perfetta sinfonia di ambiguità e allusioni in una lingua non sua. Un film che celebra gli attori nati, quelli scomparsi e quelli mancati, in un dramma familiare di raffinata malinconia. Recensione ❯
OGGI A ROMA

tel: 065745825

CINEMA Greenwich

Versione originale con sottotitoli:
17:00

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Le verità
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.47 - CONSIGLIATO SÌ
CATTIVERIE A DOMICILIO
Una commedia imperdibile, pungente e scorretta con performance attoriali memorabili. Commedia, Drammatico - Gran Bretagna, USA, Francia 2023. Durata 100 Minuti.

MYMOVIES.IT 4.00

CRITICA 2.89

PUBBLICO 3.52
Un film di Thea Sharrock. Con Olivia Colman, Jessie Buckley, Anjana Vasan, Timothy Spall Uscita 18 aprile 2024. Oggi tra i Film al cinema in 5 sale. Distribuzione Bim Distribuzione, Lucky Red.
Quando la gente di Littlehampton inizia a ricevere lettere scandalose e oscene, il sospetto cade immediatamente sulla focosa Rose, che potrebbe perdere la custodia della figlia. Espandi ▽
Fare commedia in modo arguto, sottile, raffinato, è arte sempre più rara. Appartiene di sicuro alla penna di Johnny Sweet e alla maestria registica di Thea Sharrock, che firmano un’opera deliziosa, scorretta e imperdibile. Al centro c’è un mistero da risolvere: lettere oscene piene di insulte dal mittente sconosciuto. Siamo nel primo ventennio del Novecento, le donne non sono ben viste in società, e Sharrock ne sottolinea con amara ironia a più riprese la realtà ingiustamente subalterna. L’ironia con cui Sharrock porta sullo schermo tutta questa narrazione è feroce e politicamente scorretta, ma soprattutto colpisce tutte e tutti indiscriminatamente. A tutto questo si aggiunge l’umorismo marcato, e amaro al tempo stesso, con cui si affronta in maniera narrativamente ammirevole il fenomeno contemporaneo degli “haters”, attraverso questa storia “più che vera” (avvertono i titoli di testa). Recensione ❯
OGGI A ROMA

Cinevillage Monteverde

21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 063612449

Eden Film Center

16:40
18:50
21:30
16:40
18:50
21:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it


tel: 065417926

CINEMA Madison

17:50
19:40

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

ALTRI CINEMA keyboard_arrow_down

tel: 068559493

CINEMA Mignon

21:15
17:00
19:10
21:15

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

CHIUDI keyboard_arrow_up
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Cattiverie a domicilio
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.92 - ASSOLUTAMENTE SÌ
IL RAGAZZO E L'AIRONE
Una vertiginosa odissea in cui Hayao Miyazaki rivisita i suoi film precedenti e rende omaggio alle sue influenze. Animazione, Giappone 2023. Durata 124 Minuti. Consigli per la visione: Film per tutti

MYMOVIES.IT 4.00

CRITICA 4.05

PUBBLICO 3.70
Un film di Hayao Miyazaki. Con Masaki Suda, Takuya Kimura, Kô Shibasaki, Yoshino Kimura Uscita 1 gennaio 2024. Oggi tra i Film al cinema in 2 sale. Distribuzione Lucky Red.
La crescita psicologica di un adolescente attraverso le interazioni con i suoi amici e lo zio. Espandi ▽
La guerra del Pacifico brucia Tokyo e il mondo di Mahito, un ragazzino traumatizzato dalla morte della madre, divorata dal fuoco dei bombardieri. Due anni dopo, elaborato il lutto, suo padre lascia la città per la campagna e per la cognata, da cui adesso aspetta un figlio. Mahito fatica ad accettare una nuova mamma e una nuova vita ma qualcosa lo distrae dal dolore. Un airone cenerino e ostinato lo tormenta e ‘gli parla’ conducendolo in un mondo fantastico e nascosto. Nel corso di una vertiginosa odissea in cui il protagonista attraversa una serie di soglie, livelli e portali, nella speranza di vedere la madre morta e di ritrovare la matrigna viva, Miyazaki mette in campo un immaginario ricco ed eterogeneo in cui rivisita i suoi film precedenti e rende omaggio alle sue influenze, mescolando stili e tecniche di animazione diversi e incrociando la strada di un bestiario straordinario che funge da guida per l’aldilà. Recensione ❯
OGGI A ROMA

CINEMA Troisi

Versione originale con sottotitoli:
15:00
13:30
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Il ragazzo e l'airone
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.60 - CONSIGLIATO SÌ
ENCANTO
Dai creatori di Oceania un musical scoppiettante che è racconto di rifondazione e appello all'inclusione. Animazione, Avventura, Commedia - USA 2021. Durata 99 Minuti. Consigli per la visione: Film per tutti

MYMOVIES.IT 4.00

CRITICA 3.17

PUBBLICO 3.63
Un film di Jared Bush, Charise Castro Smith, Byron Howard. Con Alvaro Soler, Luca Zingaretti, Diana Del Bufalo, Angie Cepeda Uscita 24 novembre 2021. Distribuzione Walt Disney.
Il magico lungometraggio d'animazione diretto da Jared Bush e Byron Howard. Espandi ▽
Dentro questo musical scoppiettante, così precisamente localizzato al centro dell'America Latina, in una Colombia tutta ritmo e colore, si nasconde la realtà universale dell'estrema complessità di ciò che chiamiamo famiglia; un intreccio di sentimenti, traumi, eredità, aspettative, che ci dà la vita e ce la sconvolge nello stesso momento. Encanto è una storia antica e moderna, un racconto di rifondazione: quel riposizionamento anche doloroso o violento della fondamenta della casa (leggi: famiglia) che periodicamente ha bisogno di essere messo in atto, per liberare nuove energie e includere nuove prospettive. È un racconto di tradizione e rivoluzione, che passa attraverso l'accettazione dell'imperfezione, perché non è la bella apparenza che rende felici, ma la vicinanza all'essenza. Recensione ❯
OGGI A ROMA

The Space Moderno

11:05

The Space Parco de Medici

11:00
In provincia di Roma anche a: Guidonia oppure cerca Encanto in tutta la provincia »
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Encanto
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.67 - CONSIGLIATO SÌ
FATHER AND SON
Una toccante e misurata riflessione sulla paternità, che interroga il sangue, il tempo e il sentimento. Drammatico, Giappone 2013. Durata 120 Minuti.

MYMOVIES.IT 4.00

CRITICA 3.43

PUBBLICO 3.57
Un film di Kore'eda Hirokazu. Con Masaharu Fukuyama, Machiko Ono, Yôko Maki, Lily Franky, Jun Fubuki Uscita 3 aprile 2014. Distribuzione Bim Distribuzione.
Ryota Nonomiya scopre un giorno che suo figlio biologico è stato scambiato alla nascita con un altro bambino. Espandi ▽
Nonomiya Ryota è un professionista di successo, un uomo che lavora sodo ed è abituato a vincere. Un giorno, lui e la moglie Midori ricevono una chiamata dall'ospedale di provincia dove sei anni prima è nato loro figlio, Keita, e vengono a sapere che sono stati vittima di uno scambio di neonati. Il piccolo Keita è in realtà il figlio biologico di un'altra coppia, che sta crescendo il loro vero figlio, insieme a due fratellini, in condizioni sociali più disagiate e con uno stile di vita molto differente. Ryota si trova di fronte alla necessità di una decisione terribile: scegliere il figlio naturale o il bambino che ha cresciuto e amato per sei anni? Recensione ❯
OGGI A ROMA

tel: 065745825

CINEMA Greenwich

19:15
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Father and Son
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.02 - CONSIGLIATO SÌ
X - A SEXY HORROR STORY
Vivace e riuscita rivisitazione dell'horror rurale da parte di un Ti West particolarmente ispirato. Horror, USA 2022. Durata 105 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.04

PUBBLICO 2.53
Un film di Ti West. Con Mia Goth, Jenna Ortega, Brittany Snow, Kid Cudi Uscita 14 luglio 2022. Oggi tra i Film al cinema in 1 sale. Distribuzione Midnight Factory. V.M. 18
Il set di un film porno si trasforma in un incubo senza precedenti. Espandi ▽
Nel Texas del 1979, lo scalcinato produttore Wayne intende girare un porno film con cui riassestare le sue problematiche finanze. Con lui, nel furgoncino diretto al luogo prescelto per le riprese, c'è un altrettanto scalcinato gruppetto: le attrici Maxine (fidanzata di Wayne) e Bobby-Lynne, l'attore ex marine Jackson, il regista RJ (che non nasconde le sue velleità autoriali) e la sua timida fidanzatina Lorraine, che gli fa da assistente. Il viaggio termina nell'isolata fattoria dell'anziano e scorbutico Howard, da cui Wayne ha affittato una dependance piuttosto malmessa che, all'insaputa dell'anziano, sarà il set del porno, intitolato The Farmer's Daughters. Tutto sembra perfetto e l'entusiasmo nella troupe non manca, mentre iniziano le riprese. Ma l'anziana moglie di Howard vigila e ha delle strane idee. Dopo alcuni anni dedicati in prevalenza a lavori per la televisione, West torna all'horror per il cinema con questo film che rappresenta di certo la sua migliore opera nel genere. Vivace rivisitazione simpaticamente cruenta dell'horror rurale degli anni che furono, il film vanta anche la buona prova di un cast disponibile, nel quale spicca, come sempre, l'intensa e brillante prova di una Mia Goth (La cura dal benessere) che illumina ogni scena di cui fa parte (e, sotto pesante make-up, interpreta anche Pearl!). Recensione ❯
OGGI A ROMA

CINEMA Troisi

Versione originale con sottotitoli:
22:15
Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
X - A Sexy Horror Story
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.65 - CONSIGLIATO SÌ
HIT MAN - KILLER PER CASO
Una commedia romantica travestita da thriller poliziesco, con una sceneggiatura da applausi. Commedia, Azione - USA 2023. Durata 113 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 4.00

CRITICA 3.88

PUBBLICO 3.08
Un film di Richard Linklater. Con Glen Powell, Adria Arjona, Austin Amelio, Retta Uscita 27 giugno 2024. Oggi tra i Film al cinema in 7 sale. Distribuzione Bim Distribuzione.
Un famoso killer professionista lavora ora per polizia. Decide di infrangere le regole quando decide di aiutare una donna. Espandi ▽
Gary Johnson è il killer professionista più ricercato di New Orleans. Chi lo assolda per uccidere la moglie o un socio ingombrante, però, farebbe meglio a guardarsi le spalle. Johnson, infatti, dietro i tanti travestimenti che indossa, è un professore universitario e un collaboratore della polizia. Dotato di un talento naturale per l'interpretazione drammatica, incastra uno dopo l'altro i suoi malcapitati clienti e li consegna alla giustizia. Le cose si complicano, però, quando incontra e s'invaghisce della bella Madison, disposta a tutto pur di liberarsi di un marito violento. Hit Man è a tutti gli effetti una commedia romantica travestita da thriller poliziesco, in cui il gioco degli equivoci è pompato da un'altissima posta in gioco, e ogni conversazione, ogni mossa, richiedono una performance impeccabile da parte degli attori in gioco. Commedia degli omicidi, con una sceneggiatura da applausi, il film mette in scena il denominatore comune che esiste tra l'arte dell'esistenza e quella dello spettacolo, per il tramite di un Laurence Olivier del lavoro sotto copertura. Il risultato è un susseguirsi teso e divertente di colpi di scena e di duetti e triangoli eccellenti. Recensione ❯
OGGI A ROMA

tel: 0688801283 - 0688800888

CINEMA Giulio Cesare

18:45

tel: 0688801283 - 0688800888

Quattro Fontane

17:00
19:15
Versione originale con sottotitoli:
21:15
21:15
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Hit Man - Killer per caso
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.12 - CONSIGLIATO SÌ
FLY ME TO THE MOON - LE DUE FACCE DELLA LUNA
Una commedia sull'allunaggio che incuriosisce, diverte e fa riflettere sulle manipolazioni della politica. Commedia, Drammatico - Gran Bretagna, USA 2024. Durata 132 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 2.67

PUBBLICO 3.20
Un film di Greg Berlanti. Con Scarlett Johansson, Channing Tatum, Woody Harrelson, Jim Rash Uscita 11 luglio 2024. Oggi tra i Film al cinema in 2 sale. Distribuzione Eagle Pictures.
Scritto da Rose Gilroy e basato sulla storia di Bill Kirstein e Keenan Flynn, un film sull'allunnaggio e la manipolazione politica. Espandi ▽
Cole Davis è il direttore del programma di lancio dell'atteso viaggio sulla luna dell'Apollo 11. Kelly Jones è una spregiudicata esperta di marketing che viene assunta per promuovere l'impresa spaziale il più possibile, per fomentare il popolo americano a seguire con passione la missione e gli sponsor a investirvi. Nel mezzo c'è la politica del governo Nixon, determinata a mostrare al mondo - con ogni mezzo a disposizione, oltre l'etica - che l'America approderà sulla luna ben prima della Russia. Un film-caleidoscopio, con dentro commedia, love story, dramma, metacinema e una spruzzata di thriller politico. L'opera è ambiziosa, traccia tante, forse troppe, piste narrative con una regia non particolarmente efficace, che tuttavia riesce nell'intento di intrattenere, incuriosire, divertire, commuovere e far riflettere sulle manipolazioni multiple di una politica spregiudicata, decisa a calpestare ogni etica pur di mostrare al mondo intero la sua volontà di grandezza. Channing Tatum è credibile per quanto eccessivamente ingessato, Scarlett Johansson risulta perfettamente aderente al suo ruolo. Menzione speciale infine per il villain interpretato da Woody Harrelson, che riesce nell'impresa non scontata di far piacere al pubblico un personaggio sulla carta assolutamente detestabile. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

19:00
19:00
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Fly me To the Moon - Le due facce della luna
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.33 - CONSIGLIATO SÌ
LITTLE SISTER
Con la sensibilità che lo contraddistingue, Kore-Eda entra nell'universo femminile in punta di piedi. Drammatico, Giappone 2015. Durata 128 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA 3.50

PUBBLICO 3.48
Un film di Kore'eda Hirokazu. Con Haruka Ayase, Masami Nagasawa, Kaho, Suzu Hirose Uscita 1 gennaio 2016. Distribuzione Bim Distribuzione.
Dopo Like Father, Like Son (Premio della Giuria a Cannes) e Nobody Knows (Premio Miglior Attore a Cannes) Kore-Eda Hirokazu ritorna con un altro sensibile e poetico racconto di amore sui legami familiari. Espandi ▽
Nella cittadina di Kamakura vivono tre sorelle (Sachi, Yoshino e Chika) il cui padre le ha lasciate da 15 anni per iniziare una nuova convivenza. In occasione del suo funerale le ragazze fanno la conoscenza della sorellastra adolescente Suzu che accetta volentieri l'invito ad andare a vivere con loro. Recensione ❯
OGGI A ROMA

tel: 065745825

CINEMA Greenwich

17:00
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Little Sister
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.62 - CONSIGLIATO SÌ
DOSTOEVSKIJ
I fratelli D'Innocenzo vanno controcorrente e affrontano la serialità senza falsi pudori. Lo spettatore scaverà nel proprio abisso. Drammatico, Italia 2024. Durata 279 Minuti.

MYMOVIES.IT 3.00

CRITICA 3.68

PUBBLICO 4.17
Una serie di Damiano D'Innocenzo, Fabio D'Innocenzo. Con Filippo Timi, Gabriel Montesi, Carlotta Gamba, Federico Vanni Uscita 11 luglio 2024. Oggi tra i Film al cinema in 1 sale. Distribuzione Vision Distribution. V.M. 14
Un poliziotto è alla caccia di uno spietato omicida seriale, soprannominato Dostoevskij. Espandi ▽
Enzo Vitello è un poliziotto che vive profondi tormenti causati soprattutto dal difficile rapporto con la figlia Ambra da lui abbandonata da tempo e pericolosamente avviata sulla via della tossicodipendenza. Il suo lavoro lo obbliga a confrontarsi con un serial killer, che lui e i suoi colleghi hanno soprannominato Dostoevskij perché dopo gli omicidi lascia messaggi con riflessioni sul senso della vita. Apparentemente non esistono moventi per le uccisioni e le vittime non offrono elementi per creare collegamenti tra di loro. Enzo assume su di sé la responsabilità di catturare Dostoevskij quasi come un'ossessione dettata forse da una inconfessabile vicinanza di pensiero. I fratelli D'Innocenzo affrontano la serialità senza falsi pudori e con la consapevolezza di stare andando controcorrente. Di fronte a questo passaggio dei registi alla serialità c'è da apprezzare che, sia loro che la produzione, non si siano piegati alle forche caudine della novelization globalizzata offrendo, a chi voglia coglierla, un'opportunità differente. Filippo Timi si carica sulle spalle Enzo Vitello e ci costringe ad accompagnarlo, con il peso delle sue ossessioni e con i tempi necessari per leggergli dentro, in un percorso che, grazie alle scelte di una regia capace di leggere e far emergere ogni singolo dettaglio, non può essere abbandonato. Recensione ❯
OGGI A ROMA

tel: 065745825

CINEMA Greenwich

20:30
17:45
20:30

Cinema aderente all'iniziativa Cinema Revolution
Fino al 19 settembre FILM ITALIANI ED EUROPEI SOLO 3,50 €
Maggiori info su cinemarevolution.it

Recensione | Cast | Rassegna stampa | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Dostoevskij
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.00 - CONSIGLIATO SÌ
TWISTERS
Un film che riesce a sorprendere lo spettatore. Dove ciò che conta è l'escalation. Azione, Avventura, Drammatico - 2024. Durata 117 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.00

CRITICA 3.00

PUBBLICO 3.00
Un film di Lee Isaac Chung. Con Daisy Edgar-Jones, Glen Powell, Anthony Ramos, Brandon Perea Uscita 17 luglio 2024. Oggi tra i Film al cinema in 11 sale. Distribuzione Warner Bros Italia.
L'epico disaster movie ritorna al cinema in una nuova versione per la regia di Lee Isaac Chung. Espandi ▽
Kate Cooper da ragazza ha cercato con un gruppo di amici di trovare una formula chimica che imbrigliasse la devastante forza dei tornado. Le cose non sono andate bene ed ora svolge il suo lavoro di meteorologa dietro le rassicuranti mura di un edificio newyorchese. Quando, dal recente passato, giunge un amico per cercare di convincerla a tornare in azione sul campo si lascia tentare. Incontrerà sul suo cammino Tyler Owens che, con i suoi accoliti, va a caccia di tornado per esibire le proprie gesta su Youtube. Ci sono film che vanno visti non tanto per ciò che raccontano ma per come lo fanno. Ci si sono messi in tre (Warner, Universal e Amblin) per realizzare questo che non si può propriamente definire un remake del film di Jan De Bont. Perché sono passati quasi trent'anni e nel frattempo nell'ambito del cinema di genere catastrofico abbiamo visto passare numerosi tentativi di ripetizione. Qui siamo piuttosto dinanzi a un test sul passaggio dalla potenza all'atto di nuove tecnologie non disponibili all'epoca e ora non economicamente sostenibili se non da major in coalizione. Allo spettatore non va tolta la, chiamiamola così, sorpresa. Ma si provi a contare quanti sono i tornado proposti e si osservi a mente fredda come siano collocati su una scala di complessità di devastazione. Recensione ❯
OGGI A ROMA

tel: 0636004988

CINEMA Adriano

21:40
21:40

The Space Parco de Medici

23:00
22:50

tel: 892960 (no prefisso)

Uci Cinemas Parco Leonardo

14:05
ALTRI CINEMA keyboard_arrow_down

tel: 892960 (no prefisso)

Uci Cinemas Porta di Roma

13:50
CHIUDI keyboard_arrow_up
Recensione | Cast | Rassegna stampa | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Twisters
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.45 - CONSIGLIATO SÌ
FUGA IN NORMANDIA
Un film struggente e commovente che parla di guerra e amore. Con Caine e Jackson, interpreti straordinari. Drammatico, Biografico, Guerra - Gran Bretagna, USA 2023. Durata 96 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 2.85

PUBBLICO 4.00
Un film di Oliver Parker. Con Michael Caine, Glenda Jackson, John Standing, Danielle Vitalis Uscita 20 giugno 2024. Oggi tra i Film al cinema in 3 sale. Distribuzione Lucky Red.
Ispirato a fatti realmente accaduti, il film è interpretato dai premi Oscar Michael Caine e Glenda Jackson. Espandi ▽
Dover, 2014. Bernie Jordan ha quasi novant'anni e un grande sogno: quello di partecipare al 70esimo anniversario dello Sbarco in Normandia, l'evento storico cui l'uomo ha partecipato come giovane recluta in Marina il 6 giugno del 1944. Irene detta Rene, sua moglie da 70 anni, è malata e ricoverata. Quando scopre di essere arrivato troppo tardi per prenotare il viaggio organizzato dai reduci di Dover, Bernie decide di partire da solo, con il benestare di Rene che non avverte il personale della casa di cura. Fuga in Normandia è basato sulla vera storia di Bernie Jordan, noto ai media con il soprannome di "il grande fuggitivo" per quella sua iniziativa spericolata, a quasi novant'anni. Il film è molto commovente, soprattutto nelle scene che coinvolgono gli autentici reduci dello Sbarco (bellissimo il loro ritrovarsi sulla spiaggia), e manda un messaggio contro tutte le guerre. Per interpretare questa storia delicata e profonda ci volevano due interpreti straordinari, e Parker li ha trovati in Michael Caine e Glenda Jackson, lui al suo ultimo ruolo prima del ritiro dalle scene, lei al suo ruolo finale prima della scomparsa nel 2023. Entrambi sono credibili e amabili. Recensione ❯
OGGI A ROMA

tel: 065417926

CINEMA Madison

16:00
Recensione | Cast | Rassegna stampa | Pubblico |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Fuga in Normandia
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER

MYMONETRO - GIUDIZIO MEDIO
3.46 - CONSIGLIATO SÌ
FREMONT
Un'opera pacata, romantica e dal gusto retrò che ha come sfondo uno spaccato dell'America di oggi. Drammatico, USA 2023. Durata 91 Minuti. Consigli per la visione: Ragazzi +13

MYMOVIES.IT 3.50

CRITICA 3.55

PUBBLICO 3.33
Un film di Babak Jalali. Con Anaita Wali Zada, Gregg Turkington, Jeremy Allen White, Hilda Schmelling Uscita 27 giugno 2024. Oggi tra i Film al cinema in 3 sale. Distribuzione Wanted.
Una ragazza cerca una comunità all'interno di Fremont, una città della Bay Area. Espandi ▽
Piccolo film esistenzialista dalle venature surreali, la quarta regia di Babak Jalali indaga il senso di stasi e lenisce le angosce dell’esperienza umana. Lo fa attraverso la storia di Donya, che nel vissuto autentico dell’attrice principale Anaita Wali Zada mette in risalto il tema dell’Afghanistan, delle difficoltà dell’immigrazione, e dell’ingiusto destino di tante figure che hanno pagato a caro prezzo la loro collaborazione con le forze americane nel corso degli anni. Tutto ciò rimane però sullo sfondo, perché Fremont non è un dramma che prende di petto il reale, e alle amarezze della vita e della Storia preferisce alludere soltanto. Ne esce fuori un’opera pacata dal gusto retrò, fatta di composizioni ordinate e impreziosite da un bel bianco e nero. Al suo cuore c’è un certo romanticismo e una fede incrollabile in un destino migliore, il cammino verso il quale è tappezzato da una galleria di personaggi sempre vividi e ottimisti. Recensione ❯
OGGI A ROMA

tel: 0645541398

Nuovo Cinema Aquila

19:10
21:10
19:10
21:10
Recensione | Cast | Rassegna stampa | Pubblico |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Fremont
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




MYMONETRO - GIUDIZIO MEDIO
3.16 - CONSIGLIATO SÌ
PEARL
Bizzarro prequel di X - A Sexy Horror Story, che nasconde le ambizioni autoriali di Ti West. Horror, USA 2022. Durata 102 Minuti.

MYMOVIES.IT 3.00

CRITICA 3.31

PUBBLICO N.D.
Un film di Ti West. Con Mia Goth, David Corenswet, Tandi Wright, Matthew Sunderland V.M. 14
Pearl è una ragazza degli anni '50 che vuole diventare una star ma i suoi squilibri mentali sono già evidenti. Espandi ▽
Prequel di X - A Sexy Horror Story, tratta la storia di Pearl negli anni '50 quando il suo sogno era quello di diventare una star. Recensione ❯
OGGI A ROMA

CINEMA Troisi

Versione originale con sottotitoli:
00:30
Recensione | Cast | Rassegna stampa | Pubblico |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
Pearl
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5




GUARDA IL TRAILER
THE SACRAMENT
Ti West allarga il suo target e inscena un horror del reale, che affonda nella storia americana. Horror, USA 2013. Durata 95 Minuti.

MYMOVIES.IT 3.00

CRITICA N.D.

PUBBLICO 2.81
Un film di Ti West. Con Amy Seimetz, Joe Swanberg, Kate Lyn Sheil, AJ Bowen, Kentucker Audley
Un film liberamente ispirato al suicidio di massa di Jonestown. Espandi ▽
Un film liberamente ispirato al suicidio di massa di Jonestown. Dopo l'uccisione di cinque membri di una delegazione statunitense tra cui il governatore Leo Ryan, il predicatore Jim Jones guida 909 persone a compiere il più grande suicidio di massa della storia. Recensione ❯
OGGI A ROMA

CINEMA Troisi

Versione originale con sottotitoli:
00:30
00:30
Recensione | Cast | Pubblico | Forum |
Vota da 1 a 5 stelle
Aggiungi tra i tuoi film preferiti
The Sacrament
Riceverai un avviso quando il film sarà disponibile nella tua città, disponibile in Streaming e Dvd oppure trasmesso in TV.
1
2
3
4
5



Cinema Roma
Adriano
13
Andromeda
7
Arena Garbatella
1
Atlantic
7
Barberini
10
Broadway
4
Cineland
7
Cinevillage Monteverde
1
Cinevillage Piazza Vittorio
1
Cinevillage Villa Lazzaroni
1
Eden Film Center
5
Eurcine Multisala
7
Giulio Cesare
13
Greenwich
9
Intrastevere
6
Jolly
3
Madison
15
Mignon
3
Multisala Lux
12
Multisala Odeon
7
Nuovo Cinema Aquila
3
Quattro Fontane
7
Stardust Village
6
Teatro all'Aperto Ettore Scola
1
The Space Cinema Moderno
8
The Space Cinema Parco de Medici
16
Tibur
3
Troisi
6
Provincia di Roma
Anzio
8
Civitavecchia
3
Colleferro
7
Fiano Romano
8
Frascati
6
Genzano di Roma
7
Grottaferrata
5
Guidonia
13
Trevignano Romano
3
Velletri
4
Film di oggi a Roma:
Cattivissimo Me 4
41
It Ends With Us - Siamo noi a dire basta
24
Alien - Romulus
22
Deadpool & Wolverine
20
Blink Twice
19
La vita accanto
18
L'Innocenza
17
Trap
12
Miller's Girl
5
30 anni (di meno)
4
Seventeen Tour 'Follow' Again To Cinemas
4
Il signore degli anelli - Il ritorno del re
3
Hit Man - Killer per caso
3
When in Rome
2
Borderlands
2
Twisters
2
Dostoevskij
2
Il mistero scorre sul fiume
2
Maxxxine
1
Fly me To the Moon - Le due facce della luna
1
Fremont
1
Elenco dei Cinema raggruppati per regione:
Abruzzo
Chieti
❯
L'Aquila
❯
Pescara
❯
Teramo
❯
Basilicata
Matera
❯
Potenza
❯
Calabria
Catanzaro
❯
Cosenza
❯
Crotone
❯
Reggio Calabria
❯
Vibo Valentia
❯
Campania
Avellino
❯
Benevento
❯
Caserta
❯
Napoli
❯
Salerno
❯
Emilia Romagna
Bologna
❯
Ferrara
❯
Forlì Cesena
❯
Forlì-Cesena
❯
Modena
❯
Parma
❯
Piacenza
❯
Ravenna
❯
Reggio Emilia
❯
Rimini
❯
Friuli Venezia Giulia
Gorizia
❯
Pordenone
❯
Trieste
❯
Udine
❯
Lazio
Frosinone
❯
Latina
❯
Rieti
❯
Roma
❯
Viterbo
❯
Liguria
Genova
❯
Imperia
❯
La Spezia
❯
Savona
❯
Lombardia
Bergamo
❯
Brescia
❯
Como
❯
Cremona
❯
Lecco
❯
Lodi
❯
Mantova
❯
Milano
❯
Monza Brianza
❯
Pavia
❯
Sondrio
❯
Varese
❯
Marche
Ancona
❯
Ascoli Piceno
❯
Fermo
❯
Macerata
❯
Pesaro e Urbino
❯
Rimini
❯
Molise
Campobasso
❯
Isernia
❯
Piemonte
Alessandria
❯
Asti
❯
Biella
❯
Cuneo
❯
Novara
❯
Torino
❯
Verbano Cusio Ossola
❯
Vercelli
❯
Puglia
Bari
❯
Barletta Andria Trani
❯
Barletta-Andria-Trani
❯
Brindisi
❯
Foggia
❯
Lecce
❯
Taranto
❯
Sardegna
Cagliari
❯
Carbonia Iglesias
❯
Medio Campidano
❯
Nuoro
❯
Ogliastra
❯
Olbia Tempio
❯
Oristano
❯
Sassari
❯
Sicilia
Agrigento
❯
Caltanissetta
❯
Catania
❯
Enna
❯
Messina
❯
Palermo
❯
Ragusa
❯
Siracusa
❯
Trapani
❯
Toscana
Arezzo
❯
Firenze
❯
Grosseto
❯
Livorno
❯
Lucca
❯
Massa Carrara
❯
Pisa
❯
Pistoia
❯
Prato
❯
Siena
❯
Trentino Alto Adige
Bolzano
❯
Trento
❯
Umbria
Perugia
❯
Terni
❯
Valle d'Aosta
Aosta
❯
Veneto
Belluno
❯
Padova
❯
Rovigo
❯
Treviso
❯
Venezia
❯
Verona
❯
Vicenza
❯
Box Office
Box Office, ottimo venerdì per Cattivissimo Me 4
Il mese di agosto dovrebbe chiudere con più di 3 milioni di presenze al cinema. Continua»
Classifica di venerdì 23 agosto
1° Cattivissimo Me 4
€ 813.254,00
2° It Ends With Us - Siamo noi a dire basta
€ 191.578,00
3° Alien - Romulus
€ 99.522,00
4° Deadpool & Wolverine
€ 89.395,00
5° Blink Twice
€ 37.331,00
6° La vita accanto
€ 26.771,00
7° Il signore degli anelli - Il ritorno del re
€ 24.778,00
8° Trap
€ 24.349,00
9° Inside Out 2
€ 20.802,00
10° L'Innocenza
€ 16.679,00
Vai all'analisi della giornata »
PROSSIMA SETTIMANA AL CINEMA
Coppia aperta quasi spalancata
Pericolosamente Vicini
Giustizia privata
Sapore di mare
L'uccello dalle piume di cristallo
Finchè notte non ci separi
Invelle
Freud - L'Ultima Analisi
Freud - L'Ultima Analisi
Divano di Famiglia
Paradise Is Burning
Touch
Scopri tutti i film
prossimamente al cinema »
QUESTA SETTIMANA AL CINEMA
Cattivissimo Me 4
L'Innocenza
La vita accanto
Maxxxine
It Ends With Us - Siamo noi a dire basta
Blink Twice
Sasha
30 anni (di meno)
Seventeen Tour 'Follow' Again To Cinemas
When in Rome
Trainspotting
Spider-Man - No Way Home
Profondo rosso
Scopri tutti i film al cinema »
DALLA SCORSA SETTIMANA AL CINEMA
Alien - Romulus
Spider-Man: Far From Home
Cannibal Holocaust
Europa
Scopri tutti i film
al cinema di agosto »
PROSSIMAMENTE AL CINEMA
Non aprite quella porta - 23/9/2024
Ricomincio da Taaac! - 26/9/2024
Madame Clicquot - 12/9/2024
Il maestro che promise il mare - 19/9/2024
Jung Kook: I Am Still - 18/9/2024
Come far litigare mamma e papà - 11/9/2024
Come far litigare mamma e papà - 11/9/2024
Montessori - La Nouvelle Femme - 26/9/2024
Il magico mondo di Harold - 12/9/2024
Transformers One - 26/9/2024
Speak No Evil - 11/9/2024
Stella è Innamorata - 19/9/2024
Inter - Due stelle sul cuore - 19/9/2024
La bambina segreta - 19/9/2024
La scommessa - Una notte in corsia - 12/9/2024
Scopri tutti i film
prossimamente al cinema »
 Vai alla home di MYmovies.it »

- Film
  ❯
- 2025 - 2024 - 2023 - 2022
- Tutti i film imperdibili »
- Film imperdibili 2024
- Film imperdibili 2023
- Film imperdibili 2022
- Film imperdibili 2021
- Film imperdibili 2020
- Film imperdibili 2019
- Film imperdibili 2018
- Film da vedere
- Film al cinema
- Film di
- Film di
- Novità in Dvd

- Serie TV
  ❯
- Serie TV imperdibili 2024
- Serie TV imperdibili 2023
- Serie TV imperdibili 2022
- Serie TV imperdibili 2021
- Serie TV imperdibili 2020
- Serie TV imperdibili 2019
- Serie TV 2024
- Serie TV 2023
- Serie TV 2021
- Serie TV 2020
- Serie TV 2019
- Serie TV 2018
- 10 migliori serie tv coreane di sempre

- Generi
  ❯
- Commedie
- Film Thriller
- Film Horror
- Animazione
- Azione

- Cinema
  ❯
- Roma
- Torino
- Bari
- Firenze
- Palermo
- Genova
- Pisa
- Lecce
- Bologna
- Napoli
- Reggio Calabria
- Cosenza
- Catania
- Foggia
- Modena
- Perugia
- Taranto
- Lucca

- Cinema
  ❯
- Roma
- Milano
- Torino
- Napoli
- Bari
- Bologna
- Firenze
- Bergamo
- Palermo
- Genova
- Cuneo
- Perugia
- Brescia
- Varese
- Vicenza
- Venezia
- Monza Brianza
- Catania

- Film in streaming
  ❯
- Film gratis in streaming
- Film del 2023 in streaming
- Film del 2022 in streaming
- Film del 2021 in streaming
- Film del 2020 in streaming
- Film italiani in streaming
- Film horror in streaming

- Questa settimana al cinema
  ❯
- Cattivissimo Me 4
- L'Innocenza
- La vita accanto
- Maxxxine
- It Ends With Us - Siamo noi a dire basta
- Blink Twice
- Sasha
- 30 anni (di meno)

- Dalla scorsa settimana...
  ❯
- Alien - Romulus
- Spider-Man: Far From Home
- Cannibal Holocaust
- Opera
- Europa

- Attesissimi
- Parthenope
- Il gladiatore 2
- Joker - Folie À Deux
- Nosferatu
- Kraven - Il Cacciatore
- Il Maestro e Margherita
- Il ragazzo dai pantaloni rosa
- Anora
- Love Lies Bleeding
- Non sono quello che sono
- The Substance
- Napoli - New York
- The Lord of the Rings: The War of the Rohirrim
- Iddu
- Ricomincio da Taaac!
- Paddington in Perù
- Madame Clicquot
- Berlinguer - La grande ambizione
- Io e te dobbiamo parlare
- Il maestro che promise il mare

- Appena aggiunti
- The Forge
- One Fast Move
- Labirinti
- Blame the Game
- Jung Kook: I Am Still
- Khel Khel Mein
- Dadapolis
- Trentatrè
- San Timorasso
- When in Rome

- Prossimamente
  ❯
- 26
- Pericolosamente Vicini
- Giustizia privata
- 27
- L'uccello dalle piume di cristallo
- 28
- Il Corvo
- 29
- Coppia aperta quasi spalancata
- Sapore di mare
- Finchè notte non ci separi
- Invelle
- Freud - L'Ultima Analisi
- Divano di Famiglia
- Paradise Is Burning
- Touch
- Solo per una notte
- 2
- Nightmare - Dal profondo della notte
- 5
- La sindrome degli amori passati
- Beetlejuice Beetlejuice
- Limonov
- Campo di battaglia
- Linda e il Pollo
- Sottocoperta

- The Story of Movies
- The Story of Movies - Episodio IX: Calcio e campioni
- The Story of Movies - Episodio 8: Il thriller italiano
- The Story of Movies VII: Jung Woo-Sung, 100 anni di cinema coreano
- The Story of Movies - Episodio 6: Enzo D'Alò, il cinema d'animazione
- The Story of Movies - Episodio 5: Il comico italiano
- The Story of Movies - Episodio 4: Italian families

- Box Office
  ❯
- 1 Cattivissimo Me 4
- 2 It Ends With Us - Siamo noi a dire basta
- 3 Alien - Romulus
- 4 Deadpool & Wolverine
- 5 Blink Twice
- 6 La vita accanto
- 7 Il signore degli anelli - Il ritorno del re
- 8 Trap
- 9 Inside Out 2
- 10 L'Innocenza

- Stasera in Tv
  ❯
- Con tutto il cuore
  Rete4 ore 21.25
- Ritorno al futuro parte II
  Italia 1 ore 21.2
- Ticker - Esplosione finale
  Canale 20 ore 21.03
- Paura
  Iris ore 21.1
- Terapia e pallottole
  Twenty Seven ore 21.11
- Tremors
  Italia 2 ore 21.15
- Molly's Game
  Sky Cinema 1 ore 21.15
- Scarface
  Sky Cinema 2 ore 21.15
- Il signore degli anelli - La compagnia dell'anello
  Sky Cinema Collection ore 21.15
- World War Z
  Sky Cinema Action ore 21
- Tutti per Uma
  Sky Cinema Family ore 21
- Good Kill
  Sky Cinema Suspence ore 21

- Ultime news
- Box Office, ottimo venerdì per Cattivissimo Me 4
- Stasera in tv: i film da non perdere di sabato 24 agosto 2024
- Fuoricinema 2024, un festival che unisce cinema, cultura e impegno sociale
- Divano di famiglia, guarda l’inizio del film con Ewan McGregor
- Venezia 2024, ecco i film più attesi della Sala Web su MYmovies
- Finché notte non ci separi, guarda l'inizio del film
- La Sala Web della 81. Mostra del Cinema di Venezia è online. Ecco i film da vedere in streaming su MYmovies
- Taxi Monamour, il trailer ufficiale del film [HD]
- La sindrome degli amori passati, da giovedì 5 settembre al cinema
- Divano di Famiglia, una commedia che diventa dramma famigliare
- Blink Twice, un film difficilmente classificabile, tra horror e revenge femminista
- Cattivissimo me 4 incassa altri 883mila euro e sale a 3,4 milioni

- Argomenti
A Quiet Place Tutti i film della saga di Kung Fu Panda La zona d'interesse I film e le serie che hanno raccontato il Festival di Sanremo I migliori film sul tennis Povere Creature! I film tratti da La fabbrica di cioccolato di Roald Dahl I migliori film dedicati a Giacomo Casanova I migliori film dedicati a Napoleone Bonaparte Saw Oppenheimer Checco Zalone Baby Sitter Royal Family Leonardo Da Vinci Cinquanta sfumature Pirati dei Caraibi Jurassic Park - World 007 James Bond Auto da corsa Virus Indiana Jones Unbreakable Robert Langdon Harry Potter Millennium Il signore degli anelli Fast and Furious Alice nel paese delle meraviglie Teen movie italiani Rocky Mad Max Che Guevara Terminator Alien

Home | Cinema | Database | Film | Calendario Uscite | Serie TV | Dvd | Stasera in Tv | Box Office | Prossimamente | Trailer | TROVASTREAMING
Copyright© 2000 - 2024 MYmovies.it® - Mo-Net s.r.l. Tutti i diritti riservati. È vietata la riproduzione anche parziale. P.IVA: 05056400483
Licenza Siae n. 2792/I/2742 - Credits | Contatti | Normativa sulla privacy | Termini e condizioni d'uso | Accedi | Registrati